################################################################################
#
# Copyright (c) 2009 The MadGraph5_aMC@NLO Development team and Contributors
#
# This file is a part of the MadGraph5_aMC@NLO project, an application which 
# automatically generates Feynman diagrams and matrix elements for arbitrary
# high-energy processes in the Standard Model and beyond.
#
# It is subject to the MadGraph5_aMC@NLO license which should accompany this 
# distribution.
#
# For more information, visit madgraph.phys.ucl.ac.be and amcatnlo.web.cern.ch
#
################################################################################
from __future__ import division
import subprocess
import math
import unittest
import os
import re
import shutil
import sys
import logging
import time
import tempfile   

logger = logging.getLogger('test_cmd')

import tests.unit_tests.iolibs.test_file_writers as test_file_writers

import madgraph.interface.master_interface as MGCmd
import madgraph.interface.madgraph_interface as MG5Cmd
import madgraph.interface.madevent_interface as MECmd
import madgraph.interface.amcatnlo_run_interface as aMCCmd
import madgraph.interface.reweight_interface as RGWTcmd
import madgraph.interface.common_run_interface as commonCmd
import madgraph.interface.launch_ext_program as launch_ext
import madgraph.iolibs.files as files

import madgraph.various.misc as misc
import madgraph.various.lhe_parser as lhe_parser
import madgraph.various.banner as banner_mod

_file_path = os.path.split(os.path.dirname(os.path.realpath(__file__)))[0]
_pickle_path =os.path.join(_file_path, 'input_files')

from madgraph import MG4DIR, MG5DIR, MadGraph5Error, InvalidCmd

pjoin = os.path.join

    
    


#===============================================================================
# TestCmd
#===============================================================================
class TestMECmdRWGT(unittest.TestCase):
    """this treats all the command not related to MG_ME"""
    
    def setUp(self):
        
        self.debugging = False
        if self.debugging:
            self.path = pjoin(MG5DIR, "tmp_test")
            if os.path.exists(self.path):
                shutil.rmtree(self.path)
            os.mkdir(pjoin(MG5DIR, "tmp_test"))
        else:
            self.path = tempfile.mkdtemp(prefix='acc_test_mg5')
        self.run_dir = pjoin(self.path, 'MGPROC') 
    
    def tearDown(self):

        if self.path != pjoin(MG5DIR, "tmp_test"):
            shutil.rmtree(self.path)
        
        self.assertFalse(self.debugging)

    def get_cmd(self, event=None):
        
        with misc.chdir(self.path):
            if event:   
                files.cp(event, self.path)
                event = pjoin(self.path, os.path.basename(event))
            cmd = RGWTcmd.ReweightInterface(event_path=event)
        return cmd, event
        
    def get_MEcmd(self, event):
        
        mycmd = MGCmd.MasterCmd(mgme_dir=MG5DIR)
        mycmd.use_rawinput = False
        mycmd.haspiping = False
        #misc.sprint(mgcmd, dir(mgcmd))
        mycmd.run_cmd('import model sm; generate e+ e- > mu+ mu-; output %s' % self.run_dir)
        
        #os.mkdir(pjoin(self.run_dir, 'Events'))
        os.mkdir(pjoin(self.run_dir, 'Events', 'run_01'))
        files.cp(event, pjoin(self.run_dir,'Events','run_01', 'unweighted_events.lhe.gz'))
        
        mecmd = MECmd.MadEventCmdShell(me_dir=self.run_dir)
        
        return mecmd


    def get_aMCcmd(self, event):
        
        mycmd = MGCmd.MasterCmd(mgme_dir=MG5DIR)
        mycmd.use_rawinput = False
        mycmd.haspiping = False
        #misc.sprint(mgcmd, dir(mgcmd))
        mycmd.run_cmd('import model sm; generate u u~ > mu+ mu- [QCD]; output %s' % self.run_dir)
        
        #os.mkdir(pjoin(self.run_dir, 'Events'))
        os.mkdir(pjoin(self.run_dir, 'Events', 'run_01'))
        files.cp(event, pjoin(self.run_dir,'Events','run_01', 'events.lhe.gz'))
        
        mecmd = aMCCmd.aMCatNLOCmd(me_dir=self.run_dir)
        mecmd.force_run = True
        return mecmd                

    def test_oneloop_reweighting(self):
        """ testing that we can reweight the hj sample to a loop-induced  sample
        """
        me_cmd = self.get_MEcmd(pjoin(_pickle_path, 'hj_heft.lhe.gz'))
        
        cmd_lines = """
        change model loop_sm
        change process p p > h j [QCD]
        launch
        %s/param_card_nlo.dat
        """ % _pickle_path
        
        ff = open(pjoin(self.run_dir, 'Cards', 'reweight_card.dat'),'w')
        ff.write(cmd_lines)
        ff.close()
        

        with misc.stdchannel_redirected(sys.stdout, os.devnull):
            me_cmd.run_cmd('reweight run_01 --from_cards')
        
        lhe = lhe_parser.EventFile(pjoin(self.run_dir,'Events','run_01', 'unweighted_events.lhe.gz'))
        
        solutions = [12.905371, 12.271068, 12.271753, 12.436969, 12.330121, 12.441459, 12.290359, 12.406486, 12.352107, 11.862291, 12.346005, 12.603302, 12.483697, 12.597262, 12.352434, 11.841136, 12.559252, 12.693822, 12.073114, 12.080773, 12.088188, 12.169921, 12.36124, 12.620677, 12.641769]
        for i,event in enumerate(lhe):
            
            rwgt_data = event.parse_reweight()
            #solutions.append(rwgt_data['rwgt_1'])
            self.assertTrue('rwgt_1' in rwgt_data)
            self.assertTrue(misc.equal(rwgt_data['rwgt_1'], solutions[i]))
        #misc.sprint(solutions)
        
    def test_mass_reweighting(self):
        """ testing that we can reweight the tt~ sample when increasing the top mass
        """
        me_cmd = self.get_MEcmd(pjoin(_pickle_path, 'ttbar.lhe.gz'))
        
        cmd_lines = """
        change output 2.0
        launch
        set mass mt 200
        """ 
        
        ff = open(pjoin(self.run_dir, 'Cards', 'reweight_card.dat'),'w')
        ff.write(cmd_lines)
        ff.close()
        
        with misc.stdchannel_redirected(sys.stdout, os.devnull):
            me_cmd.run_cmd('reweight run_01 --from_cards')

        #check that initial file is untouched!        
        lhe = lhe_parser.EventFile(pjoin(self.run_dir,'Events','run_01', 'unweighted_events.lhe.gz'))
        for i,event in enumerate(lhe):      
            rwgt_data = event.parse_reweight()
            for part in event:
                if part.status ==1: #final state
                    self.assertEqual(part.mass, 173)
            self.assertFalse('rwgt_1' in rwgt_data)

        # check new file
        lhe = lhe_parser.EventFile(pjoin(self.run_dir,'Events','run_01', 'rwgt_events_rwgt_1.lhe.gz'))
        solutions = [99.680499, 0.082768602, 143.50352, 181.09149, 10.047137, 277.84815, 335.8447, 429.69546, 0.33729439, 183.69371, 512.05078, 154.24208, 120.30974, 277.77287, 40.902709, 1225.9486, 310.24914, 124.02094, 82.414442, 110.40182]
        for i,event in enumerate(lhe):
            
            rwgt_data = event.parse_reweight()
            #solutions.append(event.wgt)
            self.assertTrue(misc.equal(event.scale, event.get_ht_scale(0.5)))
            for part in event:
                if part.status ==1: #final state
                    self.assertEqual(part.mass, 200)
            self.assertFalse('rwgt_1' in rwgt_data)
            self.assertTrue(misc.equal(event.wgt, solutions[i]))
        #misc.sprint(solutions)
        
    def test_nlo_reweighting(self):
        """ check identical re-weighting in ttbar 
        """
        
        me_cmd = self.get_aMCcmd(pjoin(_pickle_path, 'ttbar_nlo.lhe.gz'))
        
        cmd_lines = """
        change mode LO+NLO
        launch --rwgt_name=MYNLO
        """ 

        ff = open(pjoin(self.run_dir, 'Cards', 'reweight_card.dat'),'w')
        ff.write(cmd_lines)
        ff.close()
        
        with misc.stdchannel_redirected(sys.stdout, os.devnull):
            me_cmd.run_cmd('reweight run_01 --from_cards')
        
        lhe = lhe_parser.EventFile(pjoin(self.run_dir,'Events','run_01', 'events.lhe.gz'))
        for i,event in enumerate(lhe): 
            rwgt_data = event.parse_reweight()
            self.assertEqual(event.wgt, rwgt_data['MYNLO_nlo'])
            self.assertTrue('MYNLO_lo' in rwgt_data)
            
    def test_nlo_output2(self):
        """ check identical re-weighting in ttbar 
        """
        
        me_cmd = self.get_aMCcmd(pjoin(_pickle_path, 'hj_nlo.lhe.gz'))
        
        cmd_lines = """
        change mode NLO_tree
        change model heft
        change process p p > h
        change process p p > h j --add
        launch 
        change output 2.0
        launch
        """ 

        ff = open(pjoin(self.run_dir, 'Cards', 'reweight_card.dat'),'w')
        ff.write(cmd_lines)
        ff.close()
        
        if 1: #with misc.stdchannel_redirected(sys.stdout, os.devnull):
            me_cmd.run_cmd('reweight run_01 --from_cards')
        
        solutions = [41.511565, 41.930505, 41.511565, 41.511565, 41.586169, 41.511565, 41.511565, 41.511565, 41.511565, 42.046806, 41.511565, 44.164503, 41.511565, -41.511565, 41.511565, 41.511565, 41.511565, 41.511565, 41.511565, 41.511565, 41.511565, 41.511565, 41.778368, 41.511565, 42.05448, 41.511565, 41.511565, 41.511565, 41.511565, 41.511565, 41.511565, 41.511565, 42.115494, 41.511854, 41.511567, 41.511565, 42.00028, 42.120605, 41.514867, -41.511565, 41.511565, 45.125706, 41.511565, 42.180208, 41.511565, 41.511565, 41.511565, 41.511565, 41.511565, 41.997509, 41.511565, 41.511565, 41.511565, 41.511565, 41.511565, 41.513926, 41.511565, 41.882499, 41.511565, 41.511565, 41.511565, 41.511565, 41.511565, 47.532736, 41.511565, 41.809063, 41.511565, 41.511565, 41.511565, 41.927695, 41.511565, 41.511565, 41.555692, 41.511565, 41.511565, 41.511565, 41.511565, 41.511565, 41.511565, 41.511565, -41.511565, 41.511565, 42.029675, 41.725129, 41.511565, 41.511565, 41.511778, 41.511565, 41.511565, 41.511565, 41.511565, 41.511565, 42.050439, 41.511565, 41.511565, 41.511565, -41.511565, 42.071105, 41.511565, 41.511565]
        lhe = lhe_parser.EventFile(pjoin(self.run_dir,'Events','run_01', 'rwgt_events_tree_rwgt_1.lhe.gz'))
        lhe_orig = lhe_parser.EventFile(pjoin(self.run_dir,'Events','run_01', 'events.lhe.gz'))
        from itertools import izip
        i=-1
        #solutions = []
        for event, event_orig in izip(lhe, lhe_orig): 
            i+=1
            rwgt_data = event_orig.parse_reweight()
            #solutions.append(rwgt_data['rwgt_1_tree'])
            self.assertTrue('rwgt_1_tree' in rwgt_data)
            self.assertEqual(event.wgt, rwgt_data['rwgt_1_tree'])
            #misc.sprint(abs(event.wgt))
            self.assertTrue(misc.equal(event.wgt, solutions[i]))
            nlo1 = event.parse_nlo_weight()
            nlo2 = event_orig.parse_nlo_weight()
            #check that nloweight have been updated
            self.assertNotEqual(nlo1.total_wgt, nlo2.total_wgt)

        #misc.sprint(solutions)

    def test_loop_improved_reweighting(self):
        """ check identical re-weighting in ttbar 
        """
        
        me_cmd = self.get_aMCcmd(pjoin(_pickle_path, 'hj_fxfx.lhe.gz'))
        
        cmd_lines = """
        change mode NLO_tree
        change model loop_sm-no_b_mass
        change process p p > h [QCD]
        change process p p > h j [QCD] --add
        change process p p > h j j QED<=1 [QCD] --add
        launch --rwgt_name=MYNLO
        change output 2.0
        launch
        """ 

        ff = open(pjoin(self.run_dir, 'Cards', 'reweight_card.dat'),'w')
        ff.write(cmd_lines)
        ff.close()
        
        with misc.stdchannel_redirected(sys.stdout, os.devnull):
            me_cmd.run_cmd('reweight run_01 --from_cards')
        
        lhe = lhe_parser.EventFile(pjoin(self.run_dir,'Events','run_01', 'events.lhe.gz'))
        lhe2=  lhe_parser.EventFile(pjoin(self.run_dir,'Events','run_01', 'rwgt_events_tree_rwgt_1.lhe.gz'))
        solutions = [-113.54512, -113.58961, 113.54938, 113.48467, 113.54938, 113.12672, -113.4863, 113.54938, 113.54938, -113.26805, 105.5589, 110.41614, -113.57167, -113.26911, 113.53355, 113.54938, 113.54869, 113.43885, 113.4151, 113.43279, -113.59921, -113.54938, 113.47688, -113.41315, 113.54938, 113.54938, 113.50453, 113.54938, -113.34559, 113.41821, 113.50674, 113.54273, -113.55721, 113.5204, 113.54938, 113.9101, 113.54938, 110.76533, 85.233315, 113.38153, 113.4684, 113.41541, 113.54272, 114.08548, -113.54938, -113.48963, 113.47811, 86.336518, -113.53947, 113.62442, 113.54938, 119.1288, -113.54595, 113.39149, 113.6222, -113.50107, 114.29253, 81.891469, 113.43238, 113.59844, 112.58522, 113.53639, 111.24306, -113.52251, -113.42222, 113.53443, 113.52775, 113.59714, 101.79775, -173.10123, -113.64323, -113.52939, 113.76665, 113.38901, 113.54938, -113.85094, 112.01344, 113.52052, 113.54769, 113.54938, 113.54938, -113.74874, 114.35555, 113.49268, 113.1658, -113.54938, 113.54938, 113.45114, -106.86842, -113.25424, 113.54488, -113.70535, 113.53027, 113.02052, 113.54938, 113.54938, 113.48797, 113.5419, 113.47777, 113.53698, -113.54938, 113.58857, -113.59011, -113.53687, -113.5632, -113.54938, 50.881047, 113.54904, 113.54696, -113.53998, 98.021403, 113.52701, 113.54544, 112.85106, 113.54891, 113.54938, 113.48127, 113.27728, 113.43749, 113.4915, 113.5246, 113.48554, 113.48386, 112.76115, -113.51762, 113.54938, 112.42106, 113.47272, 115.03299, -113.53507, 113.3365, 113.48839, -113.62701, 113.54938, 113.54019, 115.84251, 113.45177, -113.5123, 113.54938, 113.53011, 109.36941, 112.78596, 113.53325, -113.62137, 113.19992, 114.3632, 113.557, 113.54938, 113.5199, 113.42012, -113.57844, 49.469316, 112.17603, 113.51455, 113.51559, 113.54938]
        for i,event in enumerate(lhe): 
            event2 = lhe2.next()
            rwgt_data = event.parse_reweight()
            #solutions.append(rwgt_data['MYNLO_tree'])
            if i < len(solutions):
                self.assertTrue(misc.equal(rwgt_data['MYNLO_tree'], solutions[i],3), '(event %s) %s != %s ' % (i, rwgt_data['MYNLO_tree'], solutions[i]))
            self.assertTrue(misc.equal(rwgt_data['MYNLO_tree'], event2.wgt, 3), '(event %s) %s != %s ' % (i, rwgt_data['MYNLO_tree'], event2.wgt))
        #misc.sprint(solutions)
            
    def test_scan_reweighting(self):
        """ testing that we can use the scan syntax and that we can assign name to weight
        """
        me_cmd = self.get_MEcmd(pjoin(_pickle_path, 'wj_zj.lhe.gz'))
        
        cmd_lines = """
        launch --rwgt_name=SINGLE
        set aEWM1 150
        launch  --rwgt_name=NAME
        set aEWM1 scan:[140,150]
        """ 
        
        ff = open(pjoin(self.run_dir, 'Cards', 'reweight_card.dat'),'w')
        ff.write(cmd_lines)
        ff.close()
        
        with misc.stdchannel_redirected(sys.stdout, os.devnull):
            me_cmd.run_cmd('reweight run_01 --from_cards')
            


        lhe = lhe_parser.EventFile(pjoin(self.run_dir,'Events','run_01', 'unweighted_events.lhe.gz'))
        # check new file
        solutions1 = [1271.6079, 1269.6829, 1267.6882, 4178.9003, 1642.2496, 1990.7289, 1919.5135, 5846.4105, 1321.7829, 3342.3616, 2102.2964, 3750.545, 1866.0121, 5055.6293, 1293.1885, 2392.5831, 2392.5831, 2804.3183, 5782.5516, 2339.1855, 2612.895, 6054.6935, 2035.3727, 3994.4565, 3116.8707, 1292.7054, 2093.4336, 4992.8379, 4087.7644, 1522.6129, 2478.3858, 2496.3302, 1386.1805, 5114.2067, 2500.2782, 1321.6502, 4866.2472, 5489.7595, 1267.7306, 1458.0087, 2478.3858, 2197.3091, 3116.8707, 1518.9617, 2569.7087, 5812.4142, 3721.3876, 1538.662, 1441.4185, 3431.8854, 1292.3439, 3228.6478, 3116.8707, 2611.9397, 5709.0362, 1900.5089, 2435.3605, 1482.1371, 2347.9413, 2478.3858, 1895.9476, 2478.3858, 5887.5244, 1552.5186, 1590.1031, 1283.6482, 6128.4796, 2388.0899, 5220.0035, 3163.5947, 2216.9967, 5593.5278, 2477.0278, 2662.4018, 1267.917, 3832.7373, 2006.4531, 6098.3264, 5336.2973, 3116.8707, 2040.4943, 1882.0148, 4183.1392, 3228.6478, 2504.1902, 1340.8677, 3116.8707, 1307.314, 4026.0025, 6029.522, 1751.389, 1988.2813, 4422.0741, 5569.1302, 1912.5803, 1270.2744, 3809.7205, 4727.1844, 1455.619, 1334.0979, 1311.1757, 2274.6351, 1321.201, 4653.3415, 3228.6478, 1880.2605, 2974.5568, 4303.6672, 3335.3585, 3228.6478, 1295.0326, 2591.5363, 3228.6478, 3157.52, 1546.9825, 5642.5176, 3116.8707, 2695.8165, 1847.5922, 3098.3163, 2959.2966, 1956.579, 2790.4342, 2392.5831, 2766.5974, 2392.5831, 1499.4724, 2214.2205, 4811.3968, 3122.2924, 1308.7355, 5373.6532, 2037.2314, 1495.3251, 4299.9047, 1705.5465, 4000.6922, 1388.6386, 2455.1661, 2784.8288, 2392.5831, 3541.3762, 4353.3251, 5009.5541, 1275.8298, 1284.2533, 1854.2404, 1665.666, 1775.9204, 1290.3684, 1807.6413, 5230.424, 3228.6478, 1759.5645, 1428.8461, 1307.1218, 1470.2203, 1343.815, 1273.6195, 1392.4008, 3116.8707, 6176.4805, 5973.2353, 1813.0731, 3905.5259, 2161.3162, 2180.7044, 4018.6183, 1662.1803, 5645.3512, 2039.1624, 3116.8707, 2080.2481, 3985.8989, 2344.4015, 5214.0435, 2791.0019, 1370.9492, 1831.7724, 1454.6271, 3389.6648, 5823.9764, 1341.9955, 1299.4998, 3113.2478, 1269.3225, 2134.6433, 5964.6184, 5077.3546, 3690.8218, 3116.8707, 3228.6478, 1305.3368, 1795.01, 2118.2377, 1926.5951, 5744.5392, 1379.7679, 1339.8179, 6006.308, 1281.5006, 3777.2343, 2392.5831, 2519.9789, 1564.3744, 6082.1715, 3438.8328, 2233.2315, 2005.7195, 4834.8915, 1282.2243, 3892.0777, 3228.6478, 3034.3716, 1603.1398, 1323.9671, 1327.278, 6120.8315, 4123.4103, 1426.1922, 1273.1435, 1282.4393, 3309.8721, 2400.7027, 2635.5076, 1304.5287, 1333.9613, 4329.4684, 1287.6483, 3666.7055, 3345.4817, 2435.7483, 1322.3836, 2231.2631, 2478.3858, 2612.895, 1930.8616, 1298.1769, 6167.1174, 3914.5563, 5995.1449, 2339.4449, 2973.0012, 3432.2393, 2406.5146, 6179.9636, 2366.69, 2022.667, 3116.8707, 1963.439, 3514.7748, 1407.1203, 1500.9503, 2392.5831, 1652.7828, 1494.0242, 2478.3858, 3228.6478, 3116.8707, 2478.3858, 1764.1892, 6015.6956, 1462.313, 3116.8707, 1272.8132, 3424.1423, 5720.5932, 1633.0101, 6046.725, 1350.3594, 1361.9488, 1269.6916, 2767.1188, 2325.6002, 2392.5831, 1521.1808, 2478.3858, 3228.6478, 2302.7037, 1463.9777, 4636.6904, 4492.5897, 1302.7891, 1269.0318, 2294.7102, 6085.1115, 1365.9059, 1317.8628, 1899.1136, 2046.6553, 2803.0674, 3250.328, 1292.2085, 1477.6303, 1972.9444, 4396.9191, 1571.9223, 1269.7637, 1655.6534, 1471.3338, 4292.4472, 3749.9559, 3228.6478, 3236.6265, 1677.0157, 6092.3826, 1597.0986, 4072.4882, 2392.5831, 2966.3999, 3491.4379, 1328.9161, 1305.7447, 1269.5172, 1326.517, 3229.0775, 3228.6478, 2295.0502, 1289.3427, 1515.8164, 3317.2146, 1930.4163, 1997.9771, 6173.5029, 1648.2612, 4854.5866, 1278.9877, 1453.2365, 5171.0833, 5213.0314, 5926.8965, 2478.3858, 5994.3785, 5748.7047, 6116.6811, 3770.9977, 4921.9483, 1781.8016, 2478.3858, 1489.43, 1267.9918, 1622.9595, 1303.2261, 1820.686, 2392.5831, 1922.6593, 3922.0825, 1569.9516, 5537.5241, 1776.5221, 1280.3089, 5084.0445, 1287.1897, 3914.4409, 1834.7263, 1268.3904, 1621.7043, 1526.7833, 2593.9391, 1495.0779, 4098.1685, 3116.8707, 1274.5923, 3116.8707, 3116.8707, 4085.7924, 4089.7701, 1322.1751, 1271.3222, 1915.8094, 3795.0725, 2478.3858, 1718.6496, 5263.9903, 6021.4598, 4447.8739, 1793.4786, 1459.7437, 4966.386, 1407.5886, 2005.7195, 1620.4809, 6178.9304, 2263.644, 3116.8707, 1637.96, 1552.8295, 5652.0104, 3577.0012, 1749.5536, 1622.787, 1537.4052, 1910.1367, 4426.095, 2392.5831, 4985.0716, 2624.5769, 1731.4217, 2039.5322, 6155.7202, 1442.0772, 3679.3696, 1273.4153, 1288.2037, 5264.6843, 1728.7738, 1843.7228, 2693.1069, 5679.7451, 1269.4801, 1274.2557, 1483.9435, 1355.6039, 1898.7175, 1454.9313, 1277.5198, 2218.6299, 2261.4081, 3116.8707, 1267.7769, 6067.9052, 1416.5563, 3116.8707, 6164.2516, 2084.0055, 1374.6299, 1424.5959, 3675.0605, 1721.9195, 1276.2706, 1592.6525, 6147.9083, 1864.4181, 1309.5215, 3656.4887, 3448.136, 1885.4181, 6168.4249, 3116.8707, 1881.0647, 2936.8359, 2048.2354, 5035.5802, 1301.6353, 2916.9298, 3116.8707, 3125.6546, 1420.3553, 1294.544, 1606.9129, 1277.8374, 3389.9079, 3228.6478, 3116.8707, 4195.0807, 2295.5614, 1434.4526, 3116.8707, 5562.6855, 5477.5663, 5600.65, 4869.5292, 1268.3248, 1989.6767, 1499.4871, 3116.8707, 1937.5786, 1838.5278, 1333.3013, 6008.899, 4176.6429, 1392.1035, 1592.88, 1267.7083, 1343.2852, 1267.6709, 3116.8707, 6179.5247, 1521.7205, 5883.8493, 2149.9109, 5809.1598, 5091.8498, 3116.8707, 1282.3674, 2375.3092, 2074.5028, 2392.5831, 3116.8707, 5444.7052, 1416.4914, 1479.6611, 1314.9547, 6166.4734, 1268.5267, 1374.529, 1267.9809, 1275.7307, 1278.1733, 1271.8418, 1343.6454, 2380.2822, 3116.8707, 4990.9654, 1443.577, 3228.6478, 4804.5842, 1576.3587, 3410.7251, 2392.5831, 2478.3858, 2478.3858, 2740.2218, 6170.7141, 1501.6303, 2400.9199, 3008.7694, 2224.8448, 3208.4756, 5465.1889, 1630.7741, 1718.3796, 1309.6225, 3350.3349, 5519.2697, 3507.7917, 2193.3609, 1833.4941, 1909.2708, 2392.5831, 2392.5831, 3331.4985, 4030.2978, 3165.0366, 2090.2234, 1549.3999, 5940.7363, 3613.8868, 1879.1357, 2491.6063, 2392.5831, 3558.1977, 5369.8549, 1325.2322, 1414.1512, 1778.0328, 2096.1978, 5242.3556, 5614.983, 3228.6478, 1634.296, 3406.6872, 5598.9928, 2005.7195, 2282.3038, 1919.4341, 1280.0514, 2068.6195, 4722.4929, 4540.5308, 3252.064, 4742.6981, 2478.3858, 1807.964, 4188.1806, 3116.8707, 2612.895, 1372.0423, 1773.7909, 2226.9374, 1358.1634, 5431.6668, 1583.3901, 4400.2552, 3750.6993, 1549.1623, 4946.4409, 4761.1881, 1302.9196, 3942.8758, 3228.6478, 3904.2785, 1351.9924, 5403.4786, 2117.5023, 2369.3226, 2501.7471, 4898.2288, 1472.4061, 3165.5139, 1296.7438, 1275.5773, 4659.8748, 1975.735, 1286.0813, 1270.3221, 5518.5578, 2295.6274, 4616.1107, 1284.6821, 3138.0183, 3228.6478, 4253.276, 2895.7838, 1362.693, 3243.2265, 1269.2683, 6173.8102, 1765.2524, 5261.0318, 1797.4155, 1494.7939, 3430.6469, 2133.6045, 3116.8707, 2772.1769, 1334.2416, 1370.6547, 1461.8602, 3724.8568, 2222.7955, 1621.078, 3116.8707, 1429.8581, 2317.4131, 5998.3758, 5231.0835, 1268.4129, 1489.5062, 1835.2638, 4270.6491, 1278.8743, 1412.8603, 1269.8486, 1374.6353, 1381.0598, 2242.3756, 2175.5759, 1329.9193, 3228.6478, 4622.7667, 1885.8464, 6021.9266, 1722.5712, 1353.5431, 3116.8707, 3092.9291, 2284.5652, 1474.4143, 1563.8967, 1335.9829, 2478.3858, 1299.8173, 2499.5381, 1573.4283, 1327.6014, 1298.3436, 1685.4275, 1488.7048, 1277.1696, 1372.1471, 2367.3728, 6167.5913, 4337.5914, 1322.788, 1787.22, 1268.3872, 1462.2436, 4051.3244, 6154.9892, 3228.6478, 1394.0226, 1272.867, 4689.6103, 1274.7255, 2478.3858, 2478.3858, 1313.9142, 2427.6507, 1801.2288, 1822.8175, 1323.4667, 1772.3131, 2005.7195, 4629.7599, 3228.6478, 1703.9355, 3116.8707, 1277.0678, 1457.2452, 1902.9052, 1563.9445, 2478.3858, 1637.79, 2574.9157, 2103.0488, 6170.6632, 2988.9637, 3850.2688, 2300.2187, 2541.4208, 1406.8609, 1267.604, 2256.9552, 5393.4061, 1296.7799, 1831.3795, 3116.8707, 1282.3443, 2171.5499, 1470.2938, 2478.3858, 1700.8189, 5936.8018, 1283.113, 3116.8707, 2249.7096, 5526.1303, 3525.1905, 2935.6102, 2392.5831, 2392.5831, 2769.475, 1536.9086, 1794.8689, 1270.8038, 1402.2506, 3179.8658, 1441.3487, 1555.9838, 3143.5713, 1459.1327, 5217.454, 1808.6903, 3267.2185, 1894.6559, 2173.2637, 2309.4699, 1457.2211, 1282.8116, 1270.1744, 1267.6041, 5974.5364, 3276.6984, 1276.4096, 4038.2533, 4853.0674, 3116.8707, 2203.57, 1304.3761, 1416.8627, 1391.5291, 1306.8477, 1666.7931, 1510.1837, 3407.2854, 6115.4128, 6154.6543, 4512.7136, 6180.828, 2443.8128, 1490.8245, 2393.1451, 1997.9758, 1267.6492, 3228.6478, 1281.3681, 1958.0254, 1276.4189, 1855.793, 1379.6082, 3269.5381, 3660.0311, 5355.5546, 2392.5831, 1420.8486, 1501.1181, 1552.1199, 5620.195, 5397.5757, 2219.2786, 3228.6478, 5040.5297, 1738.6124, 1459.4849, 1277.2459, 1523.0471, 4297.8998, 5029.1107, 1303.9776, 5462.7677, 3116.8707, 4590.4738, 3218.2143, 3922.8638, 1321.0823, 2977.6689, 1268.3296, 4862.3933, 2064.9685, 4400.8688, 2154.7829, 2007.791, 1380.6703, 6084.3525, 2694.3791, 1396.9783, 1367.682, 4447.6774, 3533.7891, 2392.5831, 1946.5628, 1595.6535, 3116.8707, 1566.6962, 1413.5323, 1369.9192, 1975.2516, 1456.5933, 1302.1943, 2005.7195, 1286.7666, 6166.057, 3335.498, 1481.4786, 5671.7663, 2037.5326, 4581.3943, 6072.7721, 2635.7606, 1866.6091, 2005.7195, 1271.5039, 1289.2159, 1551.8977, 1421.9653, 3074.145, 5935.6654, 5064.7213, 1529.2407, 5064.5418, 4695.1759, 1273.1267, 4948.4357, 2392.5831, 2594.634, 1268.1491, 3228.6478, 2563.3796, 6012.4555, 1856.3685, 2260.9478, 6180.8912, 1297.3198, 4259.9867, 3228.6478, 2478.3858, 1268.5657, 4279.6746, 1287.0666, 5696.4862, 3228.6478, 4788.2099, 1578.6014, 1360.611, 1358.8798, 1563.5132, 6164.4358, 1464.2784, 1275.521, 5352.7849, 1370.0526, 1822.3923, 2311.0656, 6128.5566, 1441.8147, 1280.4831, 1932.2678, 1979.3256, 1531.15, 2125.6755, 2069.9174, 6112.4612, 6150.3687, 3116.8707, 1269.017, 2239.2029, 3447.2741, 5211.4142, 4847.3741, 1667.1898, 1989.2023, 1282.068, 5996.0488, 1399.1198, 4938.3195, 1281.7307, 1335.6385, 1270.6204, 1655.7315, 3116.8707, 2593.1751, 1808.756, 1268.9245, 2615.7043, 1980.1921, 1307.5977, 1625.7907, 1378.4938, 1276.8578, 1286.6657, 1428.2353, 2389.9293, 2128.6012, 1458.6466, 2602.8077, 2302.2329, 1671.4936, 1314.1847, 4574.2146, 3116.8707, 2434.6934, 3116.8707, 3505.6427, 3002.0052, 1381.3935, 1313.6545, 3116.8707, 2478.3858, 3968.873, 4491.9143, 1647.8902, 1287.1651, 6019.6724, 1279.8095, 6154.5646, 1820.6514, 2478.3858, 3350.9458, 3718.759, 1510.121, 1355.7126, 3303.7132, 3228.6478, 3228.6478, 2203.8851, 6176.7138, 6089.3301, 1291.5057, 1267.8047, 2612.895, 1272.9292, 3228.6478, 3416.0911, 2478.3858, 3116.8707, 3116.8707, 2376.9313, 1811.8041, 1283.0899, 2392.5831, 3116.8707, 1357.944, 1730.5168, 3554.0289, 1618.2164, 1284.3542, 3228.6478, 3228.6478, 1687.6733, 5902.5212, 1452.8962, 2338.2359, 5237.6614, 1268.8565, 1777.0405, 2181.3294, 3329.4793, 6023.2672, 1702.0289, 1411.8308, 2565.281, 1280.967, 2205.0737, 2504.8363, 5985.1921, 5970.2329, 1288.4949, 3796.6903, 1609.1322, 4595.9423, 1939.6744, 1380.275, 2005.7195, 2478.3858, 4110.0482, 1714.3117, 2561.2165, 1578.0407, 1930.8962, 3865.1638, 5872.0333, 1802.1343, 1288.5637, 3116.8707, 1330.1438, 3228.6478, 3679.9449, 2688.0069, 3116.8707, 1344.7335, 6064.5032, 3447.3751, 4152.6044, 3116.8707, 4298.0168, 5696.6239, 3461.1434, 5153.4225, 3709.6308, 1785.5714, 1487.6991, 2392.5831, 1511.8518, 3228.6478, 1372.1376, 1604.6199, 1347.179, 1538.6198, 4601.4069, 1282.9871, 1505.7672, 5980.7441, 1325.2184, 2080.0918, 3228.6478, 4764.4671, 3290.9753, 1366.4065, 2971.1313, 3228.6478, 1268.8623, 2395.0579, 3763.8969, 2269.7189, 6161.8337, 1512.3172, 1331.6043, 1453.2253, 1620.7837, 5739.0788, 6142.7133, 3228.6478, 1493.9024, 3126.7169, 1509.8099, 1526.0168, 5743.1425, 3116.8707, 1278.6111, 4249.5576, 4028.9428, 4018.2827, 2005.7195, 2029.5184, 3837.9633, 1613.3017, 6158.3808, 3116.8707, 1550.8875, 5679.9448, 3228.6478, 1450.076, 3228.6478, 2550.6907, 6085.921, 1381.2168, 3523.697, 2207.4495, 5868.1501, 6113.3997, 1753.728, 2496.9715, 3116.8707, 1273.064, 6177.1429, 6171.1006, 3671.5734, 1383.6604, 3319.9588, 1268.6336, 1640.755, 1319.0288, 1867.2726, 1319.5783, 1915.3753, 1268.5071, 5643.7952, 3228.6478, 1734.734, 1290.2103, 2620.604, 4340.145, 1600.2986, 2962.4461, 5882.8713, 1349.8481, 1289.1452, 3116.8707, 1612.5852, 1283.4315, 2349.5296, 2631.2975, 1691.9411, 3116.8707, 1511.5128, 2516.6675, 6171.1363, 4495.9027, 2029.468, 3228.6478, 3450.0254, 4758.5609, 1942.3884, 3228.6478, 1690.3109, 2271.3629, 4843.7614, 1672.5536, 1279.8185, 6180.0142, 1518.6949, 1887.7933, 3228.6478, 1366.5925, 1291.3746, 1267.88, 2910.8536, 2478.3858, 1690.9032, 1937.1948, 2644.3841, 1609.2851, 1398.5915, 3228.6478, 3103.1234, 2410.4549, 2478.3858, 1729.5558, 2392.5831, 1421.1981, 2388.8225, 2478.3858, 6168.2845, 2977.4853, 1563.7015, 1269.7545, 4498.4265, 2884.9041, 1313.7942, 5978.1819, 1289.8863, 3466.0162, 3228.6478, 5431.8197, 1490.0894, 1405.0638, 1610.108, 1642.4586, 1278.0644, 4914.507, 3228.6478, 1608.2429, 2129.4929, 6180.0214, 3228.6478, 2191.0136, 1683.0087, 1680.8485, 1564.543, 4000.1103, 3938.8915, 1646.6072, 2614.5187, 1756.3299, 1713.2827, 1763.4746, 3512.7284, 1344.7899, 3228.6478, 3500.8003, 1278.2605, 2287.4312, 1352.5883, 1290.1582, 1562.4071, 3116.8707, 5815.32, 1272.4146, 5954.4851, 1309.4797, 5622.2134, 1517.5676, 1461.3186, 2117.7011, 1350.096, 3228.6478, 3228.6478, 2005.7195, 3388.7175, 2028.253, 3116.8707, 1274.0353, 1357.3954, 3438.2901, 1268.323, 3119.1069, 2560.6939, 2384.5671, 2392.5831, 1548.683, 1578.7223, 1409.9806, 3116.8707, 2007.7393, 4106.9013, 1396.0456, 1856.6226, 1511.3729, 3094.0131, 1307.1357, 1429.525, 1267.6206, 1273.5039, 3116.8707, 6153.7622, 4109.0293, 1382.2873, 1632.2424, 1422.2427, 2264.6974, 5645.463, 1461.2068, 1285.8296, 6164.9144, 2517.8689, 1267.8792, 1288.0424, 6104.8998, 1367.8292, 1525.9078, 1650.3029, 6082.6252, 5046.7335, 4490.4774, 3347.6083, 1746.3893, 2409.7873, 3116.8707, 2341.1731, 1267.7572, 1372.4506, 3701.2131, 1277.5862, 3524.3688, 2893.5723, 2326.3794, 2424.7424, 1300.408, 4437.4134, 2031.8065, 4540.673, 3227.4279, 1378.0187, 1997.6206, 3228.6478, 5549.3791, 1412.1476, 3824.8715, 1649.0104, 1274.5189, 1667.1546, 1571.786, 1512.6497, 3116.8707, 1454.855, 2291.2454, 2134.4454, 1383.3079, 1362.7348, 1456.8826, 1305.375, 3116.8707, 1971.6097, 1438.2802, 1908.1762, 3164.5404, 2124.4652, 2798.0857, 5004.0227, 3689.5649, 2996.3312, 5721.5588, 4357.5829, 1741.9045, 3228.6478, 1502.057, 2392.5831, 1269.231, 1394.6053, 1277.1247, 3952.6571, 4014.4134, 1473.5964, 2988.4081, 1801.6288, 1501.5193, 1664.383, 3353.7423, 2478.3858, 2612.895, 5199.6217, 1335.7554, 2392.5831, 1809.9965, 1680.5654, 1314.8022, 3228.6478, 1267.7499, 4553.2842, 2569.9155, 1424.3906, 3064.2933, 1503.5002, 3116.8707, 1638.3242, 1656.3599, 1381.4672, 1376.3054, 2916.7022, 2392.5831, 3228.6478, 2151.9237, 2058.0951, 1284.6835, 1738.7435, 2307.226, 1344.402, 3116.8707, 3318.7618, 1268.6819, 3228.6478, 3182.2139, 1268.589, 3729.5527, 4741.1305, 4476.7008, 3228.6478, 4534.6803, 1859.4489, 5896.2154, 5642.6881, 2226.9254, 3540.289, 5047.894, 2809.3302, 3045.4544, 3183.9031, 1992.0672, 3503.3726, 3817.8143, 4087.7509, 1274.1299, 1561.7342, 1708.804, 1366.6431, 1272.2703, 2478.3858, 2612.895, 5974.7641, 1392.4058, 2019.7001, 1289.8079, 4580.7212, 1271.872, 3657.2949, 5331.7869, 6042.0836, 5622.3227, 1956.3931, 5866.6395, 1510.9122, 2392.5831, 1325.4414, 4788.1971, 2151.033, 1461.6975, 1345.9985, 4062.5204, 6111.7598, 6180.8888, 1472.5903, 3627.4313, 5405.9994, 1373.1892, 6161.6783, 3228.6478, 6112.6101, 3116.8707, 2478.3858, 2192.6079, 1294.2627, 3228.6478, 3329.8346, 1644.7266, 2590.9854, 2612.895, 5738.1188, 1603.0411, 1520.8522, 1274.9079, 5170.8359, 4574.6887, 1270.4251, 6106.0672, 3116.8707, 1322.6203, 2392.5831, 2375.6051, 2026.6578, 2478.0504, 1835.568, 3228.6478, 1582.4794, 1466.9832, 2616.5505, 1295.0218, 3378.4953, 1295.8165, 1284.2773, 1284.0363, 1267.5988, 1374.3026, 1564.0104, 1269.6054, 1580.9771, 1301.6623, 2478.3858, 1269.0879, 2103.053, 1286.8875, 2151.5923, 2397.571, 2071.7447, 1358.0776, 4355.6242, 1274.3441, 3179.6985, 1342.5693, 1565.5851, 2478.3858, 1291.6963, 4184.7494, 3228.6478, 1541.648, 5213.3176, 1278.3839, 4405.3397, 2170.5813, 1272.7217, 4385.4536, 2950.3469, 5039.8583, 4620.0886, 3336.4497, 3873.4853, 1310.8712, 1691.8652, 3440.7684, 3689.8681, 3365.4561, 3751.5027, 5680.4179, 1269.6341, 3116.8707, 5317.5461, 3449.0893, 3977.8754, 1993.6032, 1980.0766, 1771.0473, 1588.7889, 5533.0136, 1452.7922, 6159.5599, 5563.9781, 1302.7561, 5034.8674, 5388.027, 1589.4205, 1435.8642, 1546.3963, 1278.9681, 1269.1023, 5243.1061, 3116.8707, 2170.1334, 4663.2932, 4705.3839, 1627.7442, 5571.842, 2491.3488, 4895.0201, 1889.0668, 2593.2589, 3116.8707, 2030.9433, 3976.5727, 5837.4025, 1561.2134, 1729.0974, 1304.9284, 2581.9429, 4270.6052, 4253.8582, 6159.775, 3333.5734, 2511.6528, 3116.8707, 1287.2192, 4261.4198, 6173.6009, 2478.3858, 1422.715, 6176.2849, 1277.3041, 2005.7195, 3116.8707, 1295.5914, 1274.8848, 3116.8707, 6180.8521, 1439.6139, 2349.1533, 3857.0389, 1321.4508, 4462.0914, 1298.5234, 4503.213, 4408.6638, 1370.4324, 2005.7195, 1973.9892, 1393.3223, 3116.8707, 1341.1791, 4734.7153, 2478.3858, 3086.3197, 2253.2413, 3228.6478, 1439.8211, 6063.1508, 2067.7506, 3228.6478, 3228.6478, 1416.2054, 5508.5728, 1840.665, 2103.946, 2817.7854, 3116.8707, 2804.7373, 1442.934, 1874.0343, 1287.061, 2064.3386, 2863.3205, 2119.9656, 3228.6478, 3409.6143, 1761.5771, 3116.8707, 1287.5644, 1355.3079, 2730.2978, 5540.3398, 2478.3858, 6179.5301, 1904.8379, 6040.5986, 1293.5863, 1270.8896, 2999.9477, 3116.8707, 3347.9354, 5356.7246, 4979.0413, 2423.7663, 1552.322, 6175.7411, 4444.6707, 1755.449, 1378.6517, 3015.2205, 5681.5453, 3228.6478, 1268.729, 2919.7782, 3741.5805, 1944.0267, 1271.1914, 1298.732, 1496.8156, 3015.7263, 3116.8707, 2571.1954, 4129.4911, 1267.8376, 2556.9854, 1399.1941, 4143.5775, 1794.8767, 5126.097, 3276.1166, 2149.2457, 3228.6478, 1475.4464, 1334.4626, 2403.6358, 1308.6822, 2321.1762, 1268.3594, 2392.5831, 1276.5887, 2005.7195, 1285.5879, 1525.1143, 3116.8707, 1485.7442, 1268.5759, 5956.2586, 5457.772, 5043.2601, 1379.2737, 1865.4903, 6159.7018, 1392.4743, 5051.3292, 6170.8714, 2515.3982, 3765.2012, 5316.1816, 1642.4015, 4734.0555, 2319.3831, 3116.8707, 6050.9519, 6049.4938, 1382.5758, 3232.2926, 1273.3452, 1400.6616, 2264.0014, 5908.936, 1738.063, 4930.0498, 2378.5589, 3228.6478, 6141.8877, 5199.8191, 3567.9743, 5730.9271, 2873.7024, 1485.0437, 1307.2166, 1375.6656, 1273.8156, 4784.9386, 5321.3794, 2352.2452, 1385.0374, 3228.6478, 1528.7535, 2022.7499, 1293.4591, 1768.9761, 4019.6616, 1607.1199, 2183.9732, 2674.3412, 6180.8908, 1372.4605, 4070.188, 5432.9308, 5576.6243, 2392.5831, 1318.99, 5707.5147, 3480.1669, 1268.4476, 1309.3884, 1563.5348, 2478.3858, 4519.0332, 5880.0817, 1706.9729, 1286.13, 2545.9382, 3116.8707, 2612.895, 1939.1928, 3593.8778, 5911.7834, 4533.5046, 2392.5831, 2478.3858, 5349.1948, 2137.0636, 2478.3858, 1519.9277, 1566.8161, 1556.3433, 3116.8707, 1536.2762, 3116.8707, 3292.5168, 1612.2411, 6103.4428, 1591.1117, 2021.6082, 3338.0373, 5324.1633, 1271.5387, 1538.1621, 6170.0538, 1352.1599, 1631.2657, 1338.6174, 2392.5831, 2612.895, 1353.6625, 3314.5025, 1519.9217, 3228.6478, 1564.7608, 3791.9582, 2988.6049, 1315.0438, 4827.2836, 1271.6528, 6177.6794, 4586.3788, 5950.8637, 1731.1377, 1284.0517, 6077.2542, 2140.6916, 1993.6175, 5508.6362, 5724.0323, 1475.6608, 2478.3858, 2478.3858, 2478.3858, 3249.257, 1270.8926, 1672.5286, 5046.9797, 1290.8159, 3234.4943, 2612.895, 5086.4844, 3116.8707, 2077.1259, 1649.5845, 6178.8645, 1675.9871, 4958.3626, 1626.0241, 3228.6478, 1352.2101, 1728.2336, 2805.4585, 2392.5831, 4944.3225, 4541.5269, 3415.187, 1268.208, 4386.329, 1437.5896, 1656.2334, 6000.7827, 6133.8707, 1814.4102, 1363.8682, 2202.6134, 1949.0683, 1444.0881, 3717.7207, 1314.7361, 2183.7345, 4158.8613, 1399.3405, 3265.5004, 3061.6946, 3857.463, 1817.7972, 6180.8697, 1885.8699, 1400.1027, 1473.1794, 1268.034, 5243.2697, 4476.8152, 1330.1195, 1836.6657, 1820.8114, 4598.0237, 1722.1418, 1530.2763, 5169.7328, 1365.4127, 2612.895, 4201.0996, 4870.129, 4405.4299, 5938.3373, 2544.6126, 4898.3058, 1317.2039, 1278.6963, 1402.9099, 1666.8239, 3119.4121, 2392.5831, 4598.5326, 1294.5545, 2505.9038, 3828.0709, 1297.5255, 5880.6549, 2064.7466, 5223.1653, 1311.1222, 1736.7269, 2217.0389, 2478.3858, 1277.5619, 2724.9631, 2500.1034, 1480.6346, 1391.8552, 4825.1378, 1322.3466, 1476.7619, 1839.4034, 3815.0256, 1346.071, 4171.7602, 1408.3086, 1270.0763, 2392.5831, 1325.7298, 3265.2183, 2431.7634, 3347.4435, 3116.8707, 1273.5337, 4055.3129, 2837.4859, 1297.3407, 1362.9446, 1274.7175, 1792.1779, 5367.9285, 4001.8757, 1339.4819, 4179.9579, 2598.3063, 5999.2434, 5520.0758, 1294.3288, 2547.6341, 1481.1917, 1312.8841, 3116.8707, 1269.0405, 3116.8707, 1514.6827, 4890.3489, 1646.1993, 1350.3694, 1485.217, 1743.7582, 4537.5375, 1352.6657, 2972.6776, 1519.4625, 3116.8707, 6073.5527, 1273.1941, 1344.0875, 3116.8707, 2837.735, 2478.3858, 2478.3858, 4713.981, 6175.9007, 1596.9817, 1979.7457, 3575.4705, 4948.7017, 2378.6505, 1586.5319, 4985.1389, 2392.5831, 3116.8707, 1283.4437, 1353.5289, 2213.6099, 1405.2949, 3116.8707, 1583.0792, 2677.466, 3668.5657, 3691.1965, 5909.7263, 6052.6448, 4009.6997, 1411.2447, 1282.8746, 1532.317, 1419.4162, 2392.5831, 1294.3043, 6078.6486, 2612.895, 1269.9658, 1341.1744, 6020.7659, 1512.7798, 1329.984, 4689.2924, 5042.2005, 2278.9207, 2615.69, 1695.7927, 4511.6497, 1461.0046, 2392.5831, 5428.108, 1289.9507, 3284.6506, 2140.6481, 2478.3858, 1296.3709, 4612.0456, 5218.8359, 3246.8539, 1584.4, 4650.8787, 5244.4077, 2392.5831, 5789.8421, 1292.5554, 1271.4626, 1352.6888, 1953.9635, 2238.3853, 2052.4725, 2478.3858, 2302.6112, 1288.5022, 2051.7515, 1278.4424, 5456.5841, 5977.7964, 1599.2211, 1760.4701, 2061.6211, 3116.8707, 2552.1387, 3167.127, 4057.3385, 3116.8707, 1485.7664, 5938.6092, 3373.7762, 2218.0938, 1275.9894, 1455.7074, 2014.4064, 1957.9702, 2027.4692, 3021.5625, 2151.1799, 4963.5198, 3050.773, 1277.6668, 1607.345, 3352.0737, 3116.8707, 3228.6478, 2340.6387, 1389.2358, 4564.1184, 1277.0376, 4687.7853, 5629.3236, 2188.6707, 1270.536, 1269.9793, 1431.265, 1760.1688, 2142.1012, 1635.9609, 1270.18, 2065.5596, 2158.4928, 1836.5673, 4128.2483, 1316.5208, 1600.9914, 1272.4963, 1338.5441, 1387.8756, 1325.225, 1416.3258, 5016.2447, 5884.055, 1267.6385, 4034.9572, 2478.3858, 6180.3342, 1307.3837, 3779.9549, 2063.1987, 1365.1758, 1267.8291, 6136.5233, 2392.5831, 1440.964, 1988.3598, 1387.2223, 3311.0156, 2402.3674, 1267.7077, 3941.5571, 5982.1878, 1743.5338, 1282.3898, 2293.1217, 1529.611, 1417.4293, 6147.3307, 3116.8707, 4226.1596, 3116.8707, 2392.5831, 1406.0343, 1964.9272, 3116.8707, 1310.1124, 1351.1465, 3005.5182, 3116.8707, 2478.3858, 3743.8134, 6018.0785, 4115.5919, 1615.7453, 3343.2346, 1267.8778, 1396.6404, 1270.9873, 5266.8614, 1398.1489, 1641.0596, 2062.6148, 1594.9473, 1304.1448, 3774.2889, 6148.9836, 1497.2213, 2478.3858, 2985.9771, 1270.6759, 2392.5831, 3850.4862, 1469.3846, 2031.0841, 1332.428, 1786.6649, 1418.9204, 1769.6996, 1522.8539, 3116.8707, 4162.6012, 1268.4836, 1579.1115, 3438.9424, 1780.8728, 1461.5933, 5478.4674, 2982.0767, 1337.5949, 3388.2571, 4234.0664, 1993.1013, 1497.4202, 1739.4225, 1743.0021, 1269.4012, 1467.2694, 5455.5571, 1390.658, 2122.5259, 1792.6592, 3422.6358, 2815.5439, 4265.1293, 1549.5235, 3501.089, 3116.8707, 2226.1949, 3620.0727, 2392.5831, 1368.1835, 5795.9346, 2338.1206, 3116.8707, 1390.0729, 1439.5415, 1906.3817, 6178.604, 1303.4554, 1688.29, 2167.5555, 2525.6799, 1335.2748, 3713.3734, 4982.648, 2392.5831, 4895.1581, 2349.2624, 1450.2234, 1298.3026, 1313.3946, 5778.178, 1471.7545, 1333.0265, 4459.2976, 3116.8707, 3116.8707, 1377.138, 3116.8707, 5051.0735, 1686.4767, 6088.3226, 1300.2765, 1423.5579, 1387.042, 1283.4878, 2919.4326, 5325.5329, 6034.0323, 4518.4179, 1272.1255, 3129.2504, 1371.434, 5828.7681, 5237.6954, 5324.1512, 1267.6291, 1500.3417, 1822.1751, 3116.8707, 1745.7949, 3116.8707, 1434.6621, 5035.0747, 2612.895, 1331.117, 3717.476, 1312.7856, 4084.2439, 1286.5633, 1301.2694, 6067.0009, 2478.3858, 2259.4654, 5694.1046, 5895.4898, 1290.6251, 2453.3775, 1694.5802, 1368.1673, 1445.3192, 5906.9379, 1474.6018, 2478.3858, 3050.4976, 1271.709, 1278.7005, 1268.0911, 2431.9214, 5760.0045, 1471.0596, 1309.0034, 1269.2331, 1298.6021, 1808.0597, 1394.5371, 1300.4097, 1411.5971, 2612.895, 1537.5175, 2392.5831, 2370.7428, 1990.5266, 3539.6503, 2370.5023, 5760.0938, 6152.2162, 1362.1507, 2478.3858, 2392.5831, 4182.8978, 3331.2458, 2796.1848, 4006.0094, 2304.1645, 2423.5033, 1306.5547, 1830.6225, 1286.6084, 3931.6354, 3116.8707, 1344.5569, 2612.895, 6126.3848, 5876.1164, 1930.7022, 1272.6382, 6002.0963, 2478.3858, 3169.9727, 2460.6462, 6044.7553, 3228.6478, 2114.2076, 3228.6478, 5924.0793, 2612.895, 5699.5968, 3228.6478, 2612.895, 3093.2432, 1644.8459, 1566.3484, 2392.5831, 5893.9959, 2502.7172, 1325.0829, 2252.5041, 5760.8755, 2478.3858, 5915.429, 1300.5853, 6054.0, 1267.5988, 3228.6478, 2392.5831, 1863.1389, 1862.7391, 3116.8707, 2612.895, 3228.6478, 1503.7629, 3116.8707, 1503.6408, 2478.3858, 1298.7707, 2392.5831, 2478.3858, 1378.0324, 1721.3206, 3228.6478, 3635.6274, 5343.3685, 1286.0607, 1617.9588, 6042.1826, 3780.5589, 1451.5534, 4890.0776, 5493.6038, 1528.8361, 1279.3225, 5625.9549, 1315.3817, 3454.8045, 6179.9051, 1278.0382, 4601.1139, 1563.7379, 2478.3858, 3496.9818, 4845.2361, 1588.9166, 4091.3925, 1436.2421, 5216.4647, 3228.6478, 3116.8707, 5343.5768, 3228.6478, 1383.7536, 3127.1183, 5708.3956, 2005.7195, 1267.7022, 1313.2281, 1356.7839, 1430.0435, 1745.0359, 1298.2838, 2093.9815, 1275.0467, 1281.1743, 5734.226, 2392.5831, 3873.9742, 1986.1611, 1331.8429, 1511.3168, 2234.8722, 5737.944, 1270.9975, 1275.8717, 3116.8707, 1365.9485, 2191.1767, 1282.6592, 1559.4978, 2392.5831, 1331.9279, 1389.1509, 1305.2379, 1392.3694, 1303.2272, 2809.2145, 4796.1929, 2410.0327, 1300.078, 2478.3858, 1824.0725, 4068.8983, 1541.6585, 2612.895, 1370.7548, 1269.8644, 1461.3392, 1291.5428, 1696.2027, 2188.8423, 3147.1969, 1796.6011, 3403.8394, 3228.6478, 2478.3858, 3228.6478, 4598.005, 1429.0877, 1286.0244, 1353.6635, 1902.1937, 1817.5364, 2392.5831, 2197.2206, 1282.081, 3790.959, 3561.8222, 5756.7221, 1467.3887, 1707.568, 1836.3382, 1405.9675, 5947.2596, 4957.9026, 6126.8381, 6042.481, 4570.6695, 2392.5831, 2478.3858, 1554.3522, 2119.2597, 1536.6788, 1420.6341, 1268.6589, 5726.5423, 3271.7723, 4025.3779, 4255.8067, 1303.6101, 1320.3412, 1623.4493, 2478.3858, 2392.5831, 1349.5981, 1506.5454, 1587.2602, 3228.6478, 5635.6993, 1322.6833, 1327.6489, 1527.8096, 1293.1284, 2392.5831, 1273.4806, 2802.5786, 6130.0539, 1421.8153, 4736.9479, 3098.0321, 3228.6478, 3116.8707, 1371.306, 5128.9993, 2055.0384, 2478.3858, 2392.5831, 3697.8664, 1542.3074, 5918.5197, 1507.8053, 2939.7645, 2478.3858, 1633.2347, 1566.0934, 2931.9279, 1267.7454, 2881.9578, 4029.1223, 1950.5169, 4866.7737, 2478.3858, 1417.5592, 1428.4062, 4465.221, 1288.8834, 5514.7016, 6140.95, 3116.8707, 1372.7969, 2421.5321, 6173.5972, 1748.631, 2203.5959, 3060.3258, 3116.8707, 2798.4184, 5581.4896, 1282.8594, 4533.6787, 1462.4309, 1809.3964, 1546.4551, 2012.3691, 1327.946, 4841.3259, 4449.1531, 1273.055, 5080.8268, 3003.8281, 1470.0296, 1552.3801, 1923.0462, 1267.9422, 1284.4269, 1311.516, 3651.9074, 1939.1849, 1549.6969, 4393.1241, 1445.9847, 1766.6494, 3761.3101, 1299.1255, 2813.2811, 5398.321, 1325.5777, 1272.3343, 3116.8707, 1383.6291, 1277.0026, 4932.9946, 2137.2227, 4805.1837, 3509.0604, 1649.9326, 6155.1409, 1546.0484, 6033.3654, 1803.9517, 1485.1216, 3116.8707, 6072.5238, 5781.7997, 4759.5621, 2159.6778, 6105.4478, 2374.3441, 2478.3858, 3971.1815, 4349.8722, 3196.3026, 1385.6249, 1363.3126, 2063.1912, 1479.8173, 3177.761, 1972.0719, 1299.4992, 1761.9487, 4076.6237, 1486.3531, 1268.6376, 3228.6478, 1593.6403, 2277.0689, 5508.1927, 4216.6456, 1275.5709, 4222.426, 2383.7963, 5474.7112, 1831.7514, 1966.3342, 2392.5831, 6012.4841, 3116.8707, 1267.7531, 3373.7477, 1319.6744, 1402.211, 3116.8707, 1752.9382, 3228.6478, 5760.9012, 4127.6384, 6036.6055, 5396.2842, 1360.2774, 1672.9897, 3423.4314, 5683.9792, 1297.9996, 1749.1605, 1307.0195, 5683.8924, 1288.4325, 1397.2273, 3043.4498, 3518.7791, 2450.0523, 2478.3858, 5241.5445, 4531.537, 1799.9689, 1888.4832, 1368.4038, 1904.336, 1338.093, 1359.3291, 5302.7266, 1931.1761, 3116.8707, 4379.1393, 5269.4967, 5525.287, 1472.911, 3228.6478, 2392.5831, 1570.0474, 2185.1106, 6095.1584, 1856.5495, 3116.8707, 1267.6372, 3116.8707, 2219.5331, 2633.771, 1372.9389, 1303.7749, 5616.4538, 1723.1805, 1475.5704, 1673.4651, 3886.8015, 5089.1527, 1638.9443, 2194.5633, 3116.8707, 3789.3283, 3228.6478, 2004.2832, 1935.6534, 2539.7935, 3533.4263, 4198.558, 6040.3527, 1324.064, 1340.3125, 1399.9161, 1276.0182, 1499.0235, 1340.5656, 1292.7885, 1414.1062, 1294.3839, 4718.5017, 3228.6478, 2392.5831, 1610.3944, 6127.1899, 6130.8323, 1267.7395, 3105.6742, 3116.8707, 1600.1331, 6078.1723, 1705.8566, 3116.8707, 1312.1027, 3228.6478, 1370.3907, 3116.8707, 1863.6184, 2162.8427, 4915.9504, 1567.9687, 3116.8707, 5524.5608, 2076.105, 3574.3531, 3116.8707, 1592.1563, 3116.8707, 6161.2294, 1784.8991, 2612.895, 1283.6163, 3116.8707, 2478.3858, 3116.8707, 1320.143, 2233.9766, 2198.0588, 2322.7487, 5600.1473, 1392.7397, 1267.6185, 5888.8591, 1299.5042, 2566.9907, 1284.1147, 2612.895, 1934.841, 2213.8124, 1320.6817, 1284.713, 2024.2512, 1270.5792, 1870.6134, 4582.4951, 2005.7195, 2839.2004, 1456.7572, 4782.2358, 5459.1733, 1288.943, 3116.8707, 3057.9111, 6028.3812, 6178.2821, 3513.8995, 1568.6445, 2478.3858, 2801.9777, 4648.6366, 1269.7908, 1381.8035, 3116.8707, 6143.5525, 5224.8035, 2603.229, 1525.191, 2392.5831, 1517.9368, 5735.8985, 2589.0216, 4540.586, 3024.3705, 2413.2322, 1363.6236, 2478.7269, 1504.2878, 2310.3208, 1289.8645, 5530.0074, 6174.5397, 3821.4608, 2440.6373, 3228.6478, 6173.646, 6125.913, 3661.2787, 5269.9696, 4058.7313, 1858.6696, 1294.0231, 1523.0779, 3586.7103, 1307.4909, 1481.277, 3116.8707, 3228.6478, 4773.5851, 1338.9394, 4279.429, 2497.5635, 1424.2752, 1307.5605, 1323.166, 4875.7135, 4623.1889, 4202.1153, 4984.5007, 1275.6, 4959.3616, 1443.0152, 3116.8707, 2888.3584, 1501.9016, 1699.9381, 1647.8209, 2128.8571, 1804.4105, 3116.8707, 1321.6845, 3116.8707, 1278.9425, 2299.3165, 2241.5886, 1739.527, 6077.3044, 3152.7701, 1426.2672, 1296.0494, 5704.9461, 1312.6796, 3116.8707, 2478.3858, 1844.0678, 2533.6022, 1425.5252, 1575.7202, 3228.6478, 1663.4771, 1522.4383, 3228.6478, 1561.3636, 5322.4211, 5027.5525, 4233.8387, 5899.4705, 2735.0726, 1915.2092, 1309.552, 1534.691, 4133.3446, 1294.9353, 1284.4246, 1521.7472, 1279.7826, 5732.6931, 4457.0959, 2196.4615, 1858.5513, 1616.0139, 1275.8689, 1871.7925, 4277.8439, 1588.7388, 5446.4291, 1317.4182, 1376.4661, 1391.5698, 6108.8877, 1269.3282, 2884.2238, 3116.8707, 1312.3853, 5352.1129, 2319.511, 2612.895, 1566.4029, 1593.9896, 1270.4573, 1311.4284, 3473.3561, 3609.7494, 2585.0333, 1509.3552, 2624.1642, 6061.2287, 1279.3913, 5656.3621, 1388.3529, 2478.3858, 1511.8711, 6029.6921, 1543.3052, 3497.7641, 4863.5868, 4324.7969, 2099.3335, 1329.6363, 4952.2213, 4459.6346, 2612.895, 1822.5861, 4570.9225, 3706.8511, 5953.6219, 1267.8443, 4473.1279, 5616.3752, 3116.8707, 2010.6877, 3091.3243, 1271.6797, 1267.8797, 1277.7851, 1882.6388, 1438.4726, 3720.8438, 3228.6478, 2478.3858, 4546.8714, 3228.6478, 1878.5049, 3117.2264, 1810.623, 1495.0752, 6142.9915, 2633.9053, 3681.0562, 1556.6694, 1288.0374, 1391.0845, 3687.2804, 6081.2566, 1710.1783, 2128.9965, 2005.7195, 3116.8707, 2392.5831, 6131.565, 3228.6478, 1332.2452, 1371.9012, 4358.6628, 2478.3858, 1504.3982, 6159.0823, 1276.2115, 1993.1835, 1340.6147, 1269.4282, 2120.8072, 5917.0259, 1395.0044, 1316.2482, 3771.0087, 2628.5002, 1281.0523, 2996.4183, 2478.3858, 1269.5793, 2451.2406, 1286.3935, 3654.4159, 3220.6358, 1354.603, 2120.3494, 1472.2778, 4134.0835, 2181.3163, 3635.7961, 1586.9203, 1549.2663, 5535.8701, 4446.5278, 3349.3451, 4279.1683, 2478.3858, 1329.5864, 4221.7094, 4698.7101, 2017.338, 1333.6345, 4813.8943, 1795.1637, 1678.7491, 2612.895, 1502.3581, 1713.043, 3228.6478, 2259.9207, 1273.689, 5961.6736, 3228.6478, 5239.7573, 3590.2264, 1376.7398, 5871.7872, 1288.31, 1872.5991, 2249.2144, 5425.5499, 1317.7686, 4843.2168, 1446.6482, 3228.6478, 1281.5841, 1275.3452, 5672.7772, 3228.6478, 2549.5499, 3228.6478, 2392.5831, 1686.802, 1495.1113, 4371.1364, 1525.9531, 1385.194, 2029.4443, 2255.9229, 1433.3413, 1487.3634, 5783.968, 1301.3014, 1277.1882, 1620.1178, 5679.1657, 3228.6478, 6120.8531, 1409.2018, 1276.2572, 4535.6242, 3952.2192, 3161.7963, 1498.0474, 1710.7513, 3228.6478, 5095.4437, 1934.8659, 1282.8158, 1269.4164, 1272.2898, 2060.3597, 6089.1266, 1277.3386, 6058.4763, 4870.9299, 6077.074, 4879.7964, 1381.5958, 3188.6426, 1279.4333, 2478.3858, 6160.8421, 1865.4631, 1324.8328, 1567.158, 3401.591, 4415.1985, 3870.5651, 1928.3079, 1282.9724, 1548.3931, 1728.0405, 4219.7915, 2091.1227, 3116.8707, 3609.1475, 1935.6659, 4971.6861, 1272.0794, 1515.9621, 1992.9483, 1267.6031, 1359.7448, 1310.3311, 1671.4272, 1962.8398, 1894.95, 3116.8707, 2478.3858, 1474.4871, 1456.4385, 5030.6872, 1649.747, 4597.4832, 1743.5153, 2478.3858, 1952.7314, 3146.153, 2392.5831, 4907.5784, 1927.7342, 6068.0005, 5917.1737, 1450.554, 1338.408, 1486.7397, 2327.2777, 1727.9488, 6151.5026, 1375.9584, 4999.6818, 4832.0033, 1521.9318, 2392.5831, 2392.5831, 1423.2639, 1932.6223, 2392.5831, 6172.9514, 2479.6348, 1293.9354, 3564.8091, 3116.8707, 2167.945, 6050.039, 4628.5705, 4331.4294, 3228.6478, 6097.7796, 1803.3517, 4886.3109, 1652.0814, 1353.9847, 2889.1853, 1311.8186, 6159.2749, 1911.3118, 1474.039, 2181.5207, 3985.9454, 4071.5258, 2392.5831, 5455.2856, 4369.4504, 4644.8488, 2628.259, 4202.9909, 4771.1847, 5551.8618, 2826.3972, 5773.6108, 1319.8212, 5606.4539, 1992.9346, 1601.9112, 1323.9157, 3973.8232, 1837.3926, 3799.3863, 1349.3464, 4099.4899, 4928.0563, 1332.256, 1267.7518, 1616.9185, 2478.3858, 3437.9972, 2392.5831, 1437.1991, 1338.3044, 3124.0718, 3947.0832, 1412.5126, 2005.1369, 4310.2643, 4708.1123, 3116.8707, 1530.2035, 5853.8725, 1674.5606, 2136.9399, 1352.2976, 2478.3858, 4625.7321, 2075.9217, 5691.3167, 1582.9213, 6175.9726, 3158.302, 1293.9129, 5555.5222, 2766.6094, 5077.2292, 1781.6287, 1275.4334, 1294.4461, 6129.7212, 2589.1713, 1284.779, 1411.8916, 1349.793, 3329.6202, 2387.4087, 4496.9974, 1386.6263, 2288.7924, 4499.6025, 2322.3342, 1892.1015, 1387.1678, 1367.2606, 1268.0904, 4245.9844, 1295.5721, 6085.5534, 1823.3352, 3482.1064, 3116.8707, 2392.5831, 5450.4843, 2478.3858, 2478.3858, 1467.6433, 5959.7503, 1763.1752, 1314.3963, 2594.7797, 3483.8088, 1295.5766, 6001.8324, 1817.3506, 3600.042, 6170.6409, 6145.4981, 6040.6787, 2508.7593, 3773.8159, 1332.247, 5813.072, 1621.306, 1587.0152, 1424.8591, 1906.6449, 1371.2735, 2129.0277, 3228.6478, 1297.5091, 1518.7085, 2868.1985, 1860.7128, 4977.2384, 1592.7324, 5378.6378, 4633.7382, 3116.8707, 1414.2289, 6149.1682, 1281.1625, 5014.5829, 2478.3858, 1362.9758, 5229.5091, 3116.8707, 4783.5778, 1269.9236, 5063.5884, 3991.1084, 3228.6478, 1272.9154, 3181.1175, 2478.3858, 2700.0951, 4059.8793, 1283.2616, 1295.2389, 2478.3858, 4897.4464, 1394.6689, 5955.6084, 2986.1952, 2478.3858, 1469.7759, 1559.2234, 1269.2983, 5886.2157, 1703.722, 3036.5314, 2575.2595, 1478.3789, 1633.1389, 2612.895, 1344.5948, 3109.0134, 5837.8169, 2530.1909, 1860.2035, 2632.9825, 1325.3031, 4001.3866, 6060.0808, 1515.2496, 3228.6478, 3228.6478, 1887.9357, 2813.0401, 5356.0033, 4516.2849, 3228.6478, 2014.1206, 3207.7995, 4071.8869, 3228.8316, 1298.7044, 3116.8707, 5984.7611, 1546.9437, 5612.9045, 1818.8091, 3794.5938, 1925.2508, 5630.7066, 2568.6138, 1282.5599, 3228.6478, 2616.7043, 1567.2965, 3116.8707, 3667.3123, 2392.5831, 1267.9852, 1274.834, 3116.8707, 1269.5521, 1368.3288, 1925.0084, 3978.4825, 1281.3138, 5710.1654, 1974.422, 1428.5853, 6155.8165, 1578.3576, 1269.9068, 1282.3023, 2594.1988, 4555.0325, 1529.3271, 1287.7576, 4656.8213, 1324.3714, 2219.3317, 1467.8667, 5195.2237, 3707.7125, 5784.1652, 1390.0244, 3300.9629, 3116.8707, 1272.4255, 1615.8013, 2392.5831, 4981.4398, 3972.5527, 2020.2189, 5468.0456, 1874.3985, 3200.3433, 4372.3771, 4410.7572, 5984.5186, 2289.993, 1274.2177, 1336.8103, 1843.6122, 3228.6478, 1504.2466, 6098.6672, 2484.9166, 1733.4463, 5573.8323, 2005.7195, 1320.755, 1749.8152, 1387.8781, 3116.8707, 2050.1331, 4374.861, 3228.6478, 5874.1936, 1273.8693, 1570.0985, 1335.2968, 1435.6983, 6163.8027, 3883.5765, 1436.0885, 6009.0576, 1268.1774, 3529.7221, 3228.6478, 3116.8707, 1372.5204, 1894.5521, 1268.7158, 1482.3436, 1297.1036, 4133.8008, 6120.1873, 4997.143, 1532.4034, 2523.2382, 3612.4883, 1484.8085, 2750.9263, 3116.8707, 1724.4852, 3354.3061, 6178.799, 2392.5831, 4309.0912, 1277.0701, 1281.3767, 1316.2222, 3228.6478, 1486.7095, 1704.2257, 1268.7229, 6161.2788, 1295.3562, 1318.3049, 1286.9207, 1417.0586, 5924.9498, 6180.6814, 1425.2212, 2134.4165, 5898.9332, 2161.5133, 2392.5831, 1376.0868, 1500.6368, 1928.67, 1923.9226, 3237.9504, 1309.1832, 3228.6478, 2704.9306, 1480.3405, 2165.2382, 1382.8329, 1554.3523, 1403.0, 2461.9421, 3228.6478, 5989.6796, 3116.8707, 1469.3508, 6120.5593, 3444.8268, 1634.6917, 3116.8707, 2360.9404, 1542.9681, 1267.6381, 3884.2847, 1271.7801, 3116.8707, 1341.8564, 1598.8283, 1763.3354, 4933.7941, 5242.575, 2556.0026, 1670.1852, 1619.9469, 1267.7624, 1335.7562, 4057.2627, 3228.6478, 1548.7028, 3081.6222, 1923.277, 5416.7561, 2032.3934, 3228.6478, 1609.9307, 1304.4158, 2392.5831, 2153.8366, 3116.8707, 1475.8284, 1362.2289, 3116.8707, 5695.8202, 2103.9515, 1390.2175, 3116.8707, 3163.833, 1426.5828, 1271.2257, 2392.5831, 3930.4519, 1281.8342, 3441.744, 6065.8155, 1461.9511, 1984.9702, 1274.5022, 1313.4153, 1689.1673, 1878.8638, 1628.7239, 3648.9559, 1414.0466, 2612.895, 1425.0817, 3228.6478, 1821.0982, 1284.2478, 1747.0359, 1333.5689, 1290.8805, 4549.3184, 1924.9473, 1368.3399, 2612.895, 3134.4927, 2392.5831, 1268.9465, 1859.6881, 2132.2365, 1584.286, 2554.8271, 3116.8707, 2392.5831, 2212.0381, 1288.0076, 2254.8237, 1268.2236, 1268.3713, 3634.4758, 5231.9932, 5997.6714, 3213.4857, 4745.1745, 2502.1608, 5330.5097, 1352.2465, 3116.8707, 3605.7243, 2322.7462, 3848.3788, 1363.213, 2467.8854, 1438.5803, 2312.5384, 3116.8707, 1330.9637, 3050.4434, 3393.7753, 1304.1074, 1294.9784, 5615.0496, 1915.8176, 5510.4028, 2523.806, 1291.2723, 2986.8398, 1938.2686, 2478.3858, 1395.022, 2478.3858, 1271.8587, 3228.6478, 1348.6656, 2612.895, 5903.1213, 5624.6403, 2206.4158, 1285.9004, 1721.1976, 2478.3858, 3872.0262, 3322.9663, 2478.3858, 1309.4056, 3116.8707, 3763.7221, 1557.9843, 1882.7398, 3163.6203, 3717.4512, 2031.23, 4494.2971, 3500.381, 5914.2718, 3302.8496, 1270.5984, 1377.7383, 2049.6212, 3228.6478, 2478.3858, 1639.6317, 4273.7788, 1681.177, 1416.4114, 6055.213, 1293.1043, 6153.6073, 3156.2977, 5118.8532, 2831.5599, 1602.6797, 6180.5478, 4903.3974, 1319.8167, 4166.372, 3228.6478, 2838.9819, 4044.9715, 2434.1201, 1681.2919, 1882.7161, 2236.9454, 1278.1293, 3116.8707, 1865.9648, 3213.505, 3228.6478, 2662.6757, 1436.484, 4044.4442, 3231.9405, 2710.2869, 1341.1939, 1504.1861, 1267.5986, 4220.3775, 1281.084, 1386.3559, 2478.3858, 1862.5742, 1526.9408, 3228.6478, 2392.5831, 5893.5056, 4181.9346, 1298.6431, 1292.5729, 2478.3858, 3029.6616, 1534.2903, 1578.6534, 1732.892, 3116.8707, 2851.751, 1300.4327, 5302.4417, 2171.4967, 2005.7195, 1267.7465, 1268.0086, 3116.8707, 3228.6478, 2378.3974, 3911.7462, 2392.5831, 4030.3298, 1339.3616, 5533.5238, 2819.3765, 2469.4222, 1320.2941, 1274.5276, 2078.6424, 5152.7076, 2612.895, 2408.9824, 1836.7153, 3496.9259, 6136.623, 3116.8707, 3116.8707, 3116.13, 1514.3298, 1430.0097, 3116.8707, 1595.0439, 1550.1261, 4791.3343, 1276.9152, 1496.9215, 1322.3325, 1461.2468, 2511.4546, 3228.6478, 5259.3694, 2612.895, 4944.5842, 2439.1943, 1327.6493, 2478.3858, 3891.8165, 1361.7507, 1553.2102, 1600.1155, 1439.4912, 1858.1335, 1652.5624, 1698.8651, 1829.0534, 1269.0855, 4731.0752, 3433.7979, 1850.8665, 5890.2509, 3116.8707, 1398.0372, 1339.8053, 2392.5831, 1278.4178, 4155.1801, 6044.6493, 1608.4687, 1960.738, 3050.1351, 1466.0397, 1267.6375, 2560.6032, 3085.6549, 5297.9057, 1267.6002, 5424.0843, 3228.6478, 1334.9566, 1345.0099, 2478.3858, 1291.5171, 5594.161, 2186.0494, 4686.3737, 5371.3822, 2508.155, 1589.0708, 1413.2428, 1589.7228, 1432.4506, 1467.0051, 3596.3485, 2612.895, 3228.6478, 3761.0128, 2735.9112, 3130.6203, 1527.6114, 1294.2676, 1403.4213, 3063.2069, 6052.4264, 1298.0889, 2478.3858, 1947.0187, 1329.3066, 2392.5831, 3156.9161, 5949.7912, 1469.6667, 1286.6918, 2478.3858, 2392.5831, 5779.3115, 1556.9899, 1283.6055, 2945.122, 1393.9764, 4961.7631, 6031.7662, 1479.6009, 5830.0265, 2392.5831, 2478.3858, 5873.7181, 1306.2505, 1267.7537, 5965.1862, 3228.6478, 4011.7852, 4104.507, 4675.8857, 1385.8444, 2392.5831, 2072.596, 2292.8071, 2420.7254, 1269.9288, 1791.8958, 1267.6061, 1301.0995, 1726.4959, 1548.1675, 3116.8707, 2478.3858, 1296.2076, 1347.5719, 4426.759, 1442.0465, 1441.665, 1268.2532, 1271.0847, 1273.4361, 1496.7828, 1784.8985, 5967.8471, 4362.4507, 3809.8658, 5769.5325, 4116.981, 1316.3312, 5014.8668, 1672.2184, 1883.4499, 2478.3858, 1537.201, 1860.9146, 1417.2975, 2661.412, 1841.7841, 2177.4381, 2214.1851, 4088.0907, 1438.7046, 3113.8894, 1831.7537, 2047.846, 2136.8046, 4999.5135, 3567.1846, 3228.6478, 2038.698, 4940.9838, 5163.9754, 2612.895, 1267.6391, 1531.1451, 1478.2392, 3228.6478, 3143.2135, 4248.1255, 1305.3495, 3824.6385, 4112.8454, 1493.5761, 1370.3439, 1383.8801, 3228.6478, 1468.551, 5001.1649, 4226.7881, 2103.3461, 1298.7096, 1349.9119, 2458.0815, 2478.3858, 2165.5476, 1423.6965, 5700.3976, 3116.8707, 3116.8707, 1527.8424, 1470.3742, 3170.1457, 2478.3858, 1778.998, 5498.7391, 5917.5779, 1281.97, 2202.8087, 1286.4926, 1911.2851, 1383.0562, 3228.6478, 5954.1477, 2396.5347, 2325.8838, 1678.1627, 1460.7244, 1690.6325, 2005.7195, 1511.0591, 2392.5831, 1404.4115, 3290.0862, 1894.8633, 2045.006, 3116.8707, 4263.8703, 1267.7777, 1563.9929, 1470.3532, 4503.4655, 1470.5776, 1960.2484, 1338.6485, 5891.5596, 1305.4587, 3228.6478, 3803.8625, 1821.7172, 1275.9963, 6081.7723, 2612.895, 4540.584, 2372.1535, 4021.9413, 4648.9655, 1271.1825, 3062.8506, 2193.5039, 1497.1647, 1686.4219, 2466.791, 2317.5455, 1293.7036, 3063.5951, 6128.179, 1290.1135, 1506.732, 1465.6461, 1400.1301, 1485.8263, 1462.7787, 2478.3858, 6104.2404, 1296.9668, 1282.441, 1302.7324, 2203.2013, 1469.0909, 1435.3812, 1285.4923, 2478.3858, 3687.6193, 3966.926, 6133.689, 2432.9599, 1301.381, 1782.2605, 1689.3117, 2392.5831, 1331.9786, 2123.0726, 5565.1091, 5998.6058, 1691.0963, 1268.017, 1735.9182, 3033.4386, 1636.2067, 2392.5831, 6175.2745, 1729.7815, 3116.8707, 3228.6478, 3228.6478, 1602.7734, 6148.2346, 1486.4358, 1267.7357, 2324.5713, 3230.4621, 4571.6919, 5928.3365, 4906.595, 2061.152, 1392.6211, 2392.5831, 1364.6779, 3228.6478, 2392.5831, 2392.5831, 3764.1546, 1982.6035, 1292.8582, 2108.7204, 1283.1307, 2570.3985, 5497.7237, 2475.5653, 1971.5595, 2231.6425, 1277.7424, 1853.6685, 1554.569, 2485.0634, 6153.8917, 4390.2213, 4620.9136, 2392.5831, 1974.0939, 1281.6288, 2911.2307, 2283.7645, 2206.4772, 1884.2998, 1886.3129, 1586.9248, 3228.6478, 1609.8364, 1272.2218, 2372.5814, 1544.3458, 5883.2769, 6054.0519, 1555.7602, 1289.9835, 4165.5566, 1267.5977, 1580.2441, 2303.1139, 1292.1951, 6166.7832, 3842.5953, 1508.5286, 1655.0693, 2075.8865, 3336.3929, 2665.8529, 1688.3197, 1566.6541, 5985.9111, 1267.6078, 4873.73, 1267.8932, 5320.0742, 5303.8397, 3116.8707, 2080.2683, 1731.7642, 1791.5977, 5425.0646, 1787.5108, 2075.3484, 3880.7019, 3553.4388, 3260.852, 3116.8707, 3107.1341, 2240.2735, 1953.203, 3186.1271, 3660.5344, 6138.854, 3228.6478, 2314.2236, 4290.8749, 1287.8565, 5713.0535, 3488.7901, 1767.3785, 5405.5376, 4117.1019, 3228.6478, 1754.1706, 2478.3858, 3116.8707, 1276.2228, 1272.2323, 1498.8615, 2056.0053, 3491.3084, 1349.6285, 1461.4643, 3228.6478, 6137.2994, 1267.6006, 3308.9428, 1741.4743, 1274.0151, 1716.9795, 2368.4729, 1316.3465, 1412.3595, 3228.6478, 1510.5407, 1308.17, 1270.748, 1498.006, 2478.3858, 4084.508, 2061.3058, 5538.6755, 2416.882, 3297.8115, 1538.8601, 1270.2177, 5952.8114, 1533.8292, 4717.6215, 3708.5554, 1314.0948, 4502.8002, 1416.6742, 1580.4226, 2269.8785, 3116.8707, 5968.8716, 2276.9095, 5453.6786, 2236.3063, 4198.0209, 3228.6478, 1272.8839, 2062.7915, 2834.4466, 3116.8707, 5587.4914, 1886.1801, 2203.666, 2098.836, 1283.225, 1395.6901, 1336.0278, 5074.4484, 1478.2411, 2762.3911, 1347.126, 5629.6675, 2456.3051, 1674.3074, 1516.1983, 6048.2665, 3228.6478, 4300.3558, 5700.7115, 1379.1437, 2478.3858, 2420.6618, 3116.8707, 5745.3389, 1909.8291, 1922.1447, 5957.6709, 1416.9635, 3029.6664, 1268.8095, 1369.3604, 3821.1056, 1277.9856, 3116.8707, 3116.8707, 5179.3268, 3257.77, 1328.7399, 2005.7195, 5992.7041, 6171.2174, 3989.5927, 1402.4667, 2288.8198, 1410.4568, 4607.6304, 1776.919, 1281.0489, 4768.7488, 1268.9166, 1630.7321, 4090.8242, 5285.8606, 6134.6672, 3209.268, 3272.1586, 1400.8816, 2256.677, 1708.0559, 5557.639, 2229.2654, 1288.5718, 5596.1226, 4507.0339, 6155.5966, 2392.5831, 1367.6651, 3873.0316, 4037.4359, 1579.1189, 3208.1039, 1792.5443, 6106.5197, 1441.6919, 1420.9191, 2189.0328, 2322.2047, 2034.6162, 1347.7931, 3349.2849, 5952.6507, 2279.2499, 1278.1023, 5447.3788, 1334.5892, 3116.8707, 3576.7725, 2429.895, 1684.6495, 5243.16, 3228.6478, 1287.963, 1603.7769, 1550.1622, 1350.1684, 1430.447, 1294.5531, 2151.6091, 1276.7923, 3228.6478, 2818.6797, 5620.7834, 1465.6734, 5841.4277, 1360.4881, 3116.8707, 1283.4985, 1338.2867, 3228.6478, 3228.6478, 1280.4287, 3543.8629, 1269.7974, 1285.6558, 3228.6478, 2478.3858, 2742.2904, 2354.8641, 6149.2334, 3378.8796, 3228.6478, 2788.7486, 5935.4587, 2612.895, 1622.0042, 1642.8102, 4770.196, 6073.1146, 1893.5931, 6019.8269, 2612.895, 4528.4001, 3116.8707, 2837.9336, 2294.87, 5829.8337, 3116.8707, 6118.1767, 5870.2979, 4867.6041, 1973.0041, 1291.5647, 1269.6589, 1414.3764, 3228.6478, 3228.6478, 5965.5818, 4021.0144, 5547.3068, 2329.1813, 1763.1258, 2005.7195, 1452.3917, 1410.9967, 2392.5831, 2387.4243, 3743.2052, 1724.5711, 1300.1688, 2580.0462, 4373.4808, 1267.951, 1521.2239, 2002.403, 3228.6478, 3797.4489, 2296.022, 1271.1427, 1711.6966, 1287.3281, 1493.6959, 6105.4337, 1812.5488, 3116.8707, 1267.6022, 1469.9108, 1734.9681, 1369.456, 1593.8116, 1276.1664, 3116.8707, 2010.1435, 1270.3721, 4672.443, 2047.8871, 2327.5753, 4678.6479, 1275.6803, 1354.1732, 5135.3168, 2138.6842, 5498.0092, 2478.3858, 1501.3961, 6157.1094, 2478.3858, 1371.9827, 1329.9963, 1270.1801, 2478.3858, 6174.8606, 2030.4573, 1538.8658, 1278.7112, 3116.8707, 1574.4058, 3383.6362, 5893.6035, 1394.4001, 2705.7065, 3300.405, 1355.1869, 5639.955, 1324.0494, 2961.3597, 1351.843, 1284.5935, 1285.2115, 4633.3114, 3308.2501, 3116.8707, 6173.2904, 5780.8083, 3228.6478, 3547.8738, 3704.7741, 4298.0466, 3782.0679, 2123.1141, 3228.6478, 5350.6962, 2189.0923, 3116.8707, 1281.1286, 1379.9612, 2392.5831, 2172.8927, 1660.6814, 2482.3095, 1900.067, 1332.0269, 2456.5337, 3059.7395, 1754.7142, 2651.9212, 3228.6478, 1801.6653, 3374.5797, 1280.3511, 4270.8751, 2074.3092, 2199.3777, 1365.4776, 2295.7209, 6179.6098, 1454.6493, 1299.8797, 1574.7134, 2392.5831, 1985.8663, 2392.5831, 1272.1912, 5398.8038, 1489.3389, 1513.4695, 1432.4787, 1269.173, 3600.3851, 1433.7272, 3116.8707, 2478.3858, 5737.6622, 1426.1634, 6095.0921, 2478.3858, 2285.0367, 1880.8981, 3860.3212, 1846.8262, 3067.4444, 2046.7077, 2530.1056, 1654.1257, 6131.5864, 1283.8695, 1869.6444, 5848.8651, 2532.6673, 1420.8432, 5880.6605, 4740.6551, 4096.8947, 1883.6211, 4385.8654, 4825.0065, 3116.8707, 1507.4987, 3228.6478, 1272.534, 1375.0096, 2322.1186, 6040.6141, 3228.6478, 6082.4486, 1374.6249, 3116.8707, 2978.2086, 5609.9203, 1390.3824, 1578.7974, 1484.7621, 5886.7819, 1943.4342, 6130.9022, 5621.3971, 1276.2341, 2869.5439, 5609.6007, 2262.7482, 5072.6314, 3132.8755, 3922.5356, 1719.5855, 2467.9862, 2825.3976, 1395.4961, 1435.8942, 1395.9204, 3116.8707, 1701.8698, 1348.7483, 2478.3858, 6119.9307, 1288.4098, 2392.5831, 6164.1505, 1344.1148, 5761.403, 3228.6478, 4376.8414, 6174.1706, 3932.2993, 1657.7972, 3116.8707, 3116.8707, 5822.9218, 3116.8707, 1701.9443, 1268.165, 2716.1812, 1663.5134, 1939.7558, 3116.8707, 5376.833, 2818.9825, 5998.4181, 2478.3858, 3404.0714, 6061.1717, 1290.3813, 4432.109, 4157.3628, 1516.6118, 1668.7222, 2624.5384, 5911.038, 2081.9333, 1523.6348, 5815.2452, 2964.9991, 5693.157, 4708.9283, 1267.6598, 2392.5831, 4098.2126, 2006.4225, 2188.4504, 2654.5409, 1344.6716, 5962.3189, 2316.0188, 4213.7437, 1320.2966, 6037.3809, 2612.895, 2128.5546, 1846.9664, 2377.9053, 2312.3667, 1342.1506, 4108.5135, 2612.895, 1524.8584, 1725.431, 3812.7031, 5007.7552, 1385.2351, 3102.0736, 2834.1194, 2478.3858, 1600.5699, 6002.0903, 1533.4581, 1377.5491, 3116.8707, 3296.6559, 3116.8707, 1268.3933, 1493.1404, 1304.5082, 4044.9429, 1607.267, 4479.2511, 1379.9591, 1294.7971, 1319.3308, 1640.8664, 3369.8191, 1998.1969, 5931.7222, 1373.5065, 1384.3376, 1444.6461, 1496.6466, 1967.4493, 1549.9954, 1272.6942, 2392.5831, 1954.4522, 3116.8707, 5302.9647, 4540.8555, 1825.7671, 3859.1946, 1814.0118, 4482.1698, 5155.0441, 3607.8745, 6091.6417, 1362.3542, 1694.2145, 2456.8448, 1359.0799, 4209.0613, 2392.5831, 1285.8444, 1912.4665, 1295.8754, 3228.6478, 1911.7961, 1659.644, 1280.6177, 3116.8707, 5886.536, 1364.0246, 2022.6334, 2392.5831, 1434.599, 1560.5325, 1335.1743, 1273.4357, 3116.8707, 1578.6734, 1321.3228, 1309.7262, 3228.6478, 2929.1178, 1268.5716, 3667.3669, 3895.8868, 1367.5159, 4229.8482, 3228.6478, 1677.6383, 5902.1925, 4980.5845, 4069.1779, 1681.1201, 4422.5423, 1343.6878, 1540.8703, 4904.5308, 3221.9891, 2478.3858, 2064.4094, 1792.7075, 1909.8052, 1298.4221, 4268.0831, 3116.8707, 1271.8913, 4594.3155, 1344.4487, 1564.8455, 2260.4944, 4642.4164, 1304.7223, 1394.5369, 3228.6478, 1346.4195, 1431.6001, 2054.9223, 1286.8903, 5937.5156, 3689.5918, 1288.8999, 1384.585, 6035.0309, 1870.0769, 2612.895, 2412.3915, 1555.0835, 2321.4412, 3996.7302, 1382.7338, 3090.842, 1326.3935, 3116.8707, 2222.7927, 1447.6299, 4462.2378, 3116.8707, 1759.7159, 1267.6183, 1523.7653, 5891.4425, 3904.8008, 5086.305, 1271.8937, 1517.2787, 1607.0298, 3116.8707, 3106.4884, 2440.7046, 1441.3509, 1439.5079, 1459.8301, 1329.168, 4653.9891, 1520.9087, 1542.2695, 1648.7809, 4451.7739, 1332.452, 3995.2814, 3191.388, 1368.8755, 6180.4993, 1377.6283, 2591.7659, 4861.2989, 3228.6478, 1812.5323, 1455.5516, 1877.3225, 3944.255, 3072.3463, 1268.9273, 1291.654, 4743.6286, 2989.4613, 2426.779, 1540.0692, 2392.5831, 5504.681, 1392.0385, 3062.0877, 1785.7044, 5039.0917, 6057.8942, 2362.9054, 3116.8707, 2029.987, 1313.9934, 3116.8707, 2478.3858, 3147.7905, 1303.5516, 4432.4714, 1341.9638, 1480.1555, 1543.6885, 4196.6059, 1878.7015, 1272.7483, 1814.0704, 5769.3235, 3116.8707, 1489.4529, 2139.2926, 1622.4941, 1841.4454, 5685.249, 3179.9365, 1400.9105, 4135.8004, 2005.7195, 2392.5831, 2107.7855, 3974.1984, 1268.0991, 2057.7645, 2392.5831, 1270.536, 5568.2291, 5317.2547, 1316.8079, 3544.6496, 1337.7086, 6052.9477, 3228.6478, 1897.3465, 1281.8472, 5370.0155, 1339.4732, 2148.5081, 6139.8685, 3376.307, 1520.2903, 1281.0107, 2392.5831, 4953.5092, 1332.5782, 3223.8367, 1274.3133, 1679.7844, 3812.2487, 6151.4148, 3116.8707, 3685.2785, 1717.7404, 4132.4965, 3116.8707, 1267.6481, 3467.2999, 4602.932, 6094.8189, 3968.0081, 2094.8856, 5108.2685, 3116.8707, 3875.4053, 5124.7355, 1502.2552, 3922.4536, 3441.282, 1324.4482, 3483.9492, 1358.331, 3069.7932, 1305.7238, 6058.5112, 1450.6489, 1449.8572, 3228.6478, 3070.7676, 1507.4338, 2213.6359, 1347.8722, 3116.8707, 1635.3322, 1908.0117, 5659.6787, 5656.663, 2392.5831, 1506.1939, 3116.8707, 3228.6478, 5786.1927, 6042.0095, 1621.2422, 3116.8707, 3116.8707, 2392.5831, 2426.6325, 1322.5997, 1599.4361, 1539.4071, 4746.1685, 1361.1477, 1335.7783, 4331.17, 2612.895, 3116.8707, 1322.3779, 1324.9171, 6178.1418, 1276.157, 4531.2554, 2478.3858, 3116.8707, 1271.6585, 3228.6478, 3114.7355, 1427.5027, 4013.001, 1746.2102, 1668.0378, 1288.6383, 2985.6899, 1272.5863, 2338.9091, 3116.8707, 3549.444, 3228.6478, 3307.0616, 2622.0336, 4229.2023, 3626.486, 2555.5784, 1446.6999, 5236.4344, 1364.6301, 2624.7194, 4658.0238, 3661.413, 2561.7203, 2392.5831, 2004.9612, 3116.8707, 1483.8142, 3228.6478, 1857.348, 1280.8782, 1588.7736, 1576.7375, 3280.4977, 1736.0598, 4824.6965, 2037.9754, 6146.187, 5204.5866, 1313.6435, 2546.0574, 1356.857, 6063.4581, 6146.7406, 3116.8707, 2251.048, 3116.8707, 1375.2405, 5100.8656, 3228.6478, 1404.903, 2612.895, 3228.6478, 5915.1451, 2450.4009, 1607.0565, 1430.8109, 3116.8707, 1374.7255, 3116.8707, 6116.7196, 2017.768, 5221.1224, 1275.1889, 1364.493, 1513.5301, 3228.6478, 3116.8707, 1272.6178, 1267.6406, 5142.1238, 2654.3929, 1377.6392, 1454.4696, 2392.5831, 1858.8817, 1979.5912, 1344.9141, 1379.29, 2392.5831, 6151.9483, 3326.4991, 5154.0599, 3613.3832, 2609.5725, 4137.8557, 1277.6093, 3380.1103, 2329.9872, 5491.6864, 5007.9094, 6064.6312, 1819.1707, 2989.2536, 1407.5126, 1437.2302, 3116.8707, 1768.3323, 2162.1051, 1633.0948, 1427.901, 1280.2588, 5073.7538, 3914.9926, 6054.9675, 1763.9074, 3074.5736, 2478.3858, 1340.1698, 2478.3858, 2222.3952, 1624.0497, 4926.8292, 1268.2151, 3674.3125, 3116.8707, 1376.9932, 1397.2925, 1299.2292, 1272.3398, 1551.246, 6179.4302, 1873.1378, 4628.5852, 1282.0232, 1779.3327, 2097.8303, 2392.5831, 4468.3871, 3105.5499, 5285.8356, 5262.8666, 1341.7436, 1583.4598, 1857.8073, 1280.0722, 1566.3501, 3860.6277, 2187.3678, 1611.1328, 1270.4906, 2224.7148, 6173.2242, 1269.7847, 1435.4374, 1443.9588, 2277.7127, 1548.85, 2300.3141, 4047.4796, 5081.787, 1346.5393, 4572.5382, 5730.2372, 1352.3491, 3791.5173, 2002.2871, 3583.3221, 1575.6977, 1273.7026, 1269.6753, 3015.4078, 1447.4002, 5691.8602, 3250.1071, 5923.6647, 1623.2971, 3228.6478, 4957.9814, 6163.9293, 2478.3858, 1586.5841, 6117.2282, 4977.1756, 2139.369, 1351.3337, 3044.456, 3109.2906, 1274.1493, 3228.6478, 5325.2695, 2478.3858, 1693.9883, 1331.757, 1484.1957, 1271.96, 1395.9666, 1845.2339, 2670.0548, 1406.2213, 1406.0563, 1391.9305, 2555.595, 4160.4748, 2416.0849, 1272.9819, 6144.993, 1932.9888, 1430.1346, 4590.794, 4428.1542, 2262.5945, 1304.3714, 1353.6141, 6180.0408, 1282.9917, 5788.1842, 3116.8707, 3228.6478, 6019.2133, 4768.0294, 1305.6057, 2107.6022, 3170.4142, 2385.3695, 5634.8095, 4976.9026, 1380.9531, 5594.7946, 2216.4573, 4191.7434, 3353.2951, 2210.4613, 6156.4481, 2351.0325, 1647.399, 5018.1225, 4216.2931, 4898.0121, 1470.0754, 3389.2097, 3328.9296, 2387.2443, 1732.8444, 3627.2079, 5352.3786, 1276.4116, 1365.4486, 5838.463, 5114.6455, 2533.7217, 1300.1759, 1513.4205, 3228.6478, 1389.7823, 2271.7892, 1405.8575, 3228.6478, 5829.9549, 4354.1527, 1387.8933, 1283.3547, 1925.4698, 3837.2214, 3398.7116, 3228.6478, 1268.1138, 3228.6478, 5592.4799, 1331.4191, 3228.6478, 1930.9461, 1338.4351, 1309.5612, 1268.4895, 1301.974, 5700.8516, 4474.1654, 2860.4241]
        solutions2 = [620.94211, 640.89372, 632.59227, 2193.5747, 722.48846, 1494.5936, 834.54776, 5164.0233, 713.52501, 1567.7857, 913.66724, 1846.4634, 812.13116, 11937.885, 679.01147, 2048.6462, 2048.6462, 1255.2486, 13418.128, 2018.9218, 2451.0452, 6384.5992, 884.25098, 6638.0875, 3608.6928, 615.35894, 1638.5222, 11628.855, 7045.215, 929.4469, 2203.174, 2291.9711, 783.96211, 12214.153, 2299.1576, 618.12037, 2940.413, 4041.1577, 633.00949, 655.82686, 2203.174, 1792.8205, 3608.6928, 925.50196, 1133.9183, 5023.8388, 1825.0796, 946.84539, 650.38218, 4559.7358, 615.36406, 3880.8935, 3608.6928, 2509.4367, 4651.5482, 1374.7545, 2183.0628, 885.95612, 2033.4898, 2203.174, 824.63124, 2203.174, 13019.863, 688.8908, 1003.3208, 665.97187, 7186.926, 2101.2428, 3485.8468, 1457.9545, 965.2824, 4306.2084, 2257.0724, 1180.9135, 627.43179, 1908.1321, 871.69863, 11204.445, 3705.8548, 3608.6928, 1563.3013, 1350.9104, 7479.6781, 3880.8935, 2306.2949, 734.95317, 3608.6928, 616.1351, 6773.7216, 12009.183, 765.31909, 863.86065, 8643.2624, 13595.607, 1390.4475, 642.45849, 5885.2832, 2763.0031, 655.03432, 727.4366, 616.57842, 1913.7632, 712.85824, 2675.2594, 3880.8935, 1348.6609, 1348.5338, 8054.0154, 1563.357, 3880.8935, 681.39686, 1144.8784, 3880.8935, 3761.2281, 686.87785, 13616.071, 3608.6928, 1198.1503, 1307.1586, 1419.4309, 1339.9774, 850.27839, 1247.8436, 2048.6462, 1235.1987, 2048.6462, 904.52075, 964.01511, 10688.544, 1433.4868, 616.28919, 3782.2515, 1558.7377, 668.51666, 2304.9259, 1134.7695, 6664.7346, 786.58346, 2218.0178, 1244.8623, 2048.6462, 1698.3489, 8298.3174, 11712.246, 618.24537, 615.96198, 807.24582, 731.51579, 775.19136, 615.42007, 788.07794, 12716.162, 3880.8935, 1198.8419, 646.35286, 616.11513, 873.23982, 738.20267, 619.42524, 635.25907, 3608.6928, 8343.1132, 5805.3555, 790.2979, 1964.5477, 940.03627, 948.78624, 6741.7878, 1084.5581, 4453.5661, 885.903, 3608.6928, 1619.5772, 6601.6496, 1024.4221, 12649.801, 1248.1457, 629.26515, 1287.3202, 654.70613, 4428.4173, 5070.3646, 622.12439, 615.51001, 1428.1718, 639.8569, 1698.6499, 12553.161, 12041.857, 1802.9295, 3608.6928, 3880.8935, 615.93976, 1241.8568, 1674.5449, 1408.7973, 13506.03, 777.11257, 733.79257, 6017.754, 616.44959, 5760.1934, 2048.6462, 2335.267, 693.22766, 11422.535, 4581.6518, 972.71144, 1391.4525, 2898.9105, 663.88511, 1953.9919, 3880.8935, 1382.4596, 707.63643, 618.51724, 719.77631, 7079.724, 2144.6986, 826.46949, 648.76051, 664.20338, 4188.833, 2122.8549, 1167.1554, 693.2361, 727.28407, 2333.1947, 671.60908, 5350.6327, 4294.3841, 1068.0361, 618.24407, 971.80906, 2203.174, 2451.0452, 1414.4113, 615.44759, 9797.4507, 1971.6704, 5943.1758, 2019.3522, 3292.0833, 1625.597, 2132.867, 9093.7532, 1034.9687, 1538.469, 3608.6928, 1457.7148, 1680.3469, 639.62134, 906.10744, 2048.6462, 1073.8141, 668.06526, 2203.174, 3880.8935, 3608.6928, 2203.174, 1204.4095, 6083.0335, 657.26098, 3608.6928, 619.96835, 1620.3133, 13547.699, 718.95342, 6318.418, 745.37618, 757.96348, 640.91785, 1235.4743, 1996.4637, 2048.6462, 677.60618, 2203.174, 3880.8935, 1959.0093, 657.81789, 2656.0353, 9004.3245, 691.11385, 624.26182, 1946.0494, 6665.5597, 627.93157, 617.51212, 825.95963, 1571.9409, 1254.5802, 4017.1583, 677.72955, 881.14303, 1470.4969, 8516.1863, 696.00649, 641.11625, 1077.0911, 874.42657, 7999.4138, 5656.8214, 3880.8935, 3978.4929, 1101.6169, 11287.319, 705.36936, 2100.9709, 2048.6462, 3276.2271, 1664.6991, 721.6254, 694.70923, 623.41577, 718.91515, 1497.4271, 3880.8935, 1001.2841, 673.91578, 922.10728, 1551.9324, 1413.8248, 1504.4826, 9540.4833, 724.79681, 2924.871, 658.93189, 654.24683, 12468.509, 3473.4291, 5544.5378, 2203.174, 5938.1696, 4786.0055, 7024.9457, 5736.4262, 11267.868, 1225.7352, 2203.174, 893.75597, 627.09522, 1040.0266, 615.75752, 793.41573, 2048.6462, 835.87655, 6334.7202, 981.06043, 13564.196, 1219.3222, 660.99374, 12073.528, 615.62308, 6303.3249, 799.18537, 636.65786, 1038.6145, 933.95871, 2474.6021, 899.80655, 7091.7189, 3608.6928, 618.85762, 3608.6928, 3608.6928, 7036.4257, 2115.6938, 618.20872, 621.20924, 832.98468, 5828.6128, 2203.174, 1150.152, 12846.932, 12085.997, 8774.57, 782.30782, 862.08586, 3079.4808, 639.76295, 1391.4525, 1037.239, 8510.8676, 1896.2438, 3608.6928, 1056.9632, 689.00406, 4473.3428, 5036.0754, 1186.835, 1039.8325, 683.41465, 1387.2625, 2428.7564, 2048.6462, 3106.6118, 1161.5927, 1165.243, 1561.9548, 10138.54, 843.31837, 5396.3155, 619.55594, 615.54167, 3567.4064, 1162.1064, 802.89549, 1196.7466, 13595.851, 623.47483, 619.04444, 887.88683, 625.31551, 1372.4344, 654.80672, 656.56211, 1825.6346, 1892.6933, 3608.6928, 633.39974, 11598.18, 816.2509, 3608.6928, 7881.7328, 1624.9614, 771.61065, 645.0116, 1791.6122, 1154.0064, 618.05204, 1006.1504, 10329.191, 1328.4435, 616.37904, 1778.3666, 1636.0151, 820.22205, 8007.6134, 3608.6928, 818.40299, 1327.4551, 889.86489, 3181.9695, 615.63961, 1316.4274, 3608.6928, 1435.4664, 820.27999, 615.35544, 709.05618, 617.45166, 1598.1407, 3880.8935, 3608.6928, 2208.0768, 1947.4266, 648.13862, 3608.6928, 4223.5621, 4012.2737, 13613.736, 2944.8109, 625.92804, 1493.1612, 904.53647, 3608.6928, 1423.2766, 800.75185, 726.54677, 6035.5275, 2191.5606, 635.17287, 703.79077, 628.72345, 622.41193, 629.07918, 3608.6928, 8566.8185, 677.79815, 5331.4618, 1721.2849, 5010.9453, 12110.266, 3608.6928, 664.09712, 1039.0635, 901.38822, 2048.6462, 3608.6928, 3936.5184, 816.18212, 663.12237, 617.08245, 7946.29, 625.37501, 630.23076, 634.73047, 653.53286, 657.62856, 620.73498, 738.01603, 1041.4303, 3608.6928, 3115.2515, 651.08271, 3880.8935, 10652.443, 988.11816, 4493.5212, 2048.6462, 2203.174, 2203.174, 1221.3066, 8086.5681, 670.71296, 2123.2285, 3379.0811, 1835.2753, 1484.9167, 13446.562, 1048.8354, 752.16987, 699.35555, 1572.8411, 4112.9069, 1675.6505, 954.52166, 798.67804, 1386.1349, 2048.6462, 2048.6462, 1560.9205, 2065.5201, 1458.8146, 1633.8968, 958.5417, 5618.6052, 1748.3417, 1347.2198, 2283.394, 2048.6462, 4972.1179, 3774.3431, 618.74131, 813.69976, 776.04532, 910.96533, 3526.2122, 4365.8585, 3880.8935, 719.44449, 1608.9745, 13613.124, 1391.4525, 1926.0526, 834.51425, 616.78971, 1602.9854, 10215.889, 9253.3963, 1511.4869, 2781.9769, 2203.174, 1257.7763, 7503.1468, 3608.6928, 2451.0452, 629.55838, 1216.0115, 969.8276, 753.86623, 3907.2672, 995.88476, 8532.9834, 5659.6185, 958.28237, 3050.947, 10421.909, 691.27375, 6420.7635, 3880.8935, 6261.7613, 624.43671, 13301.14, 1673.4697, 1036.2184, 1100.2019, 11144.91, 660.65589, 3782.7276, 683.5815, 653.26441, 9882.7051, 1474.2624, 669.43571, 642.5787, 13539.309, 1947.5335, 2632.5484, 667.45828, 3709.2, 3880.8935, 7810.5812, 1304.7843, 627.09941, 1506.0686, 639.69391, 8210.377, 770.88797, 3560.6069, 1244.8048, 899.50205, 1624.5567, 1697.117, 3608.6928, 1238.1508, 620.4719, 767.34407, 864.33749, 1827.6108, 1832.0927, 1037.9103, 3608.6928, 646.67382, 1011.7324, 5964.4372, 12718.8, 636.74946, 666.50222, 799.40676, 7893.984, 658.75193, 812.33021, 641.34691, 630.25966, 778.49386, 1862.655, 1759.78, 619.61366, 3880.8935, 9685.9393, 820.40113, 12081.629, 1154.7754, 624.81143, 3608.6928, 3591.1695, 1929.6869, 661.33646, 974.40727, 729.53745, 2203.174, 615.52709, 1099.1162, 696.56255, 720.14179, 615.45466, 1111.3435, 892.97969, 617.69218, 629.58658, 2066.0849, 7980.8247, 2341.039, 714.67439, 1232.3351, 636.64469, 864.74538, 6884.0833, 7653.9118, 3880.8935, 792.31803, 648.21237, 10040.813, 651.74439, 2203.174, 2203.174, 616.93728, 1064.1278, 1249.4858, 794.29002, 618.43003, 1214.222, 1391.4525, 9722.9626, 3880.8935, 1132.8852, 3608.6928, 655.81305, 655.57335, 1377.8616, 693.06977, 2203.174, 720.78026, 2438.1852, 914.00092, 8084.7111, 3330.6814, 6044.4599, 1954.9739, 2375.0431, 639.54296, 631.18228, 1885.6361, 13273.849, 615.39774, 797.8078, 3608.6928, 664.06299, 1753.7041, 873.31809, 2203.174, 745.24058, 12741.239, 616.14141, 3608.6928, 1874.1913, 13549.774, 1687.3744, 1326.7742, 2048.6462, 2048.6462, 1236.7206, 683.23577, 782.87308, 643.75338, 801.0669, 1467.6838, 842.54526, 690.15475, 3723.9538, 656.20055, 3481.2966, 1258.6721, 4065.2513, 824.08961, 1756.2889, 1970.0261, 859.40315, 616.19393, 642.20367, 630.20487, 5813.249, 4092.4523, 654.70329, 6826.9495, 10908.567, 3608.6928, 1802.415, 615.85331, 816.57585, 635.00654, 616.08699, 1089.8493, 916.03646, 1609.3619, 10945.898, 10166.117, 2518.8672, 8790.9372, 1071.9366, 666.95753, 1047.5662, 1504.4808, 629.33276, 3880.8935, 616.47803, 1450.465, 617.9896, 807.88917, 631.6261, 4071.8932, 5326.6842, 3744.858, 2048.6462, 643.83841, 906.28774, 961.5118, 13618.011, 3832.8219, 966.32472, 3880.8935, 11864.669, 1173.7822, 656.31776, 656.1094, 678.27042, 2303.0246, 11808.815, 692.56575, 3977.7892, 3608.6928, 2603.7015, 3927.0202, 6337.9371, 618.02589, 1350.2837, 636.40511, 10957.579, 897.1964, 8536.075, 1728.5494, 872.27719, 631.92144, 11394.366, 1197.4055, 636.59631, 764.14703, 2450.7989, 1693.1963, 2048.6462, 1435.1853, 704.82819, 3608.6928, 694.08101, 641.57453, 628.99018, 858.26418, 858.73571, 690.38411, 1391.4525, 670.3913, 7933.798, 1563.4451, 663.74352, 4533.2354, 1559.1587, 9467.609, 11539.862, 1167.2844, 1331.2293, 1391.4525, 621.03753, 615.4764, 961.26909, 821.98729, 1405.3683, 12748.423, 11981.6, 936.62037, 11980.74, 2724.458, 619.74835, 11403.998, 2048.6462, 1146.4391, 635.59589, 3880.8935, 2416.2985, 12168.39, 1318.2368, 1891.963, 8859.2335, 684.31113, 7842.7309, 3880.8935, 2203.174, 625.27681, 2285.8307, 615.63411, 4610.8926, 3880.8935, 2838.7843, 698.47657, 756.5168, 626.13056, 692.91146, 7886.8985, 866.91105, 653.16549, 13154.473, 629.02571, 794.11556, 1008.7606, 7188.0517, 650.51056, 661.26123, 839.9424, 1479.1158, 681.16631, 924.06468, 899.37093, 6971.3982, 7557.39, 3608.6928, 624.29043, 1857.6796, 4608.3983, 3470.5602, 2915.3221, 732.10653, 1492.5159, 663.65308, 12309.932, 797.73973, 11352.165, 663.15001, 620.75936, 643.31418, 1077.1802, 3608.6928, 1145.7038, 788.53322, 638.60779, 1157.0895, 1480.2884, 696.93879, 716.20235, 775.74942, 617.81206, 670.25116, 828.63593, 1046.0302, 925.37029, 860.919, 2491.7186, 1004.6334, 733.77706, 616.97457, 9429.8595, 3608.6928, 2181.8924, 3608.6928, 1674.2077, 1364.0247, 778.85061, 704.11409, 3608.6928, 2203.174, 6529.6061, 9000.8352, 1068.2393, 615.62526, 12102.631, 660.22147, 10168.411, 793.40156, 2203.174, 1573.229, 1823.1641, 673.69168, 625.3423, 1543.4771, 3880.8935, 3880.8935, 959.30501, 8356.5236, 11328.649, 676.80354, 628.03448, 2451.0452, 648.33656, 3880.8935, 4510.2362, 2203.174, 3608.6928, 3608.6928, 2082.2537, 1262.5165, 665.1594, 2048.6462, 3608.6928, 753.62836, 1164.1707, 1706.9741, 713.32671, 666.98928, 3880.8935, 3880.8935, 1113.947, 5420.904, 654.13459, 2017.3462, 12744.964, 638.38028, 1219.9511, 1768.4872, 4246.6806, 12069.032, 745.71652, 811.23795, 2419.8957, 661.99918, 1804.7245, 2307.4751, 5879.2428, 5787.2714, 672.76687, 1880.8284, 1024.5152, 2609.8171, 843.08399, 631.81138, 1391.4525, 2203.174, 2133.1224, 750.56055, 1129.6716, 698.26883, 1414.4569, 6103.7842, 13094.406, 1250.5987, 615.51669, 3608.6928, 619.65702, 3880.8935, 5398.3985, 1194.1074, 3608.6928, 739.21283, 6469.9252, 4608.7193, 7338.6023, 3608.6928, 2303.1355, 4611.3341, 1644.5842, 12391.165, 5506.771, 779.09785, 665.8791, 2048.6462, 674.30173, 3880.8935, 768.93678, 708.19303, 741.89686, 946.79954, 9573.0589, 665.00906, 911.28388, 12432.71, 717.44232, 903.85028, 3880.8935, 10439.354, 1535.5355, 762.77342, 1346.6097, 3880.8935, 638.39985, 2113.1631, 5709.4617, 989.52122, 7816.6231, 918.33467, 724.64703, 855.15601, 1037.5794, 13516.439, 7414.2376, 3880.8935, 898.54642, 1436.0923, 673.5821, 679.32954, 13508.744, 3608.6928, 617.19827, 7792.8029, 2064.3929, 2055.5493, 1391.4525, 1547.9833, 1912.1248, 711.4668, 10067.111, 3608.6928, 688.29689, 13595.683, 3880.8935, 851.81039, 3880.8935, 1124.4214, 6673.7685, 778.66171, 4856.5207, 960.92797, 5259.4295, 6983.1312, 766.25677, 2293.1373, 3608.6928, 619.79145, 9340.1173, 9646.4768, 5368.1549, 632.75927, 4218.5096, 637.59686, 1060.1318, 617.69377, 812.65532, 710.99368, 1394.0959, 637.12127, 4448.974, 3880.8935, 758.6648, 615.42672, 2526.3353, 8233.0628, 1014.6549, 1341.74, 13042.875, 623.92529, 673.649, 3608.6928, 1028.3798, 616.08829, 2036.1403, 1165.0109, 741.75561, 3608.6928, 674.18219, 2329.1684, 8102.1349, 9021.4503, 881.68025, 3880.8935, 1637.2574, 2801.5803, 844.23677, 3880.8935, 1117.0084, 990.2823, 10859.567, 1096.4733, 660.23558, 8623.2805, 925.21388, 1358.3348, 3880.8935, 762.97379, 615.38545, 634.12741, 1313.0743, 2203.174, 741.34901, 1422.7691, 1171.6851, 709.95031, 637.07188, 3880.8935, 3617.5816, 1055.8557, 2203.174, 1163.0323, 2048.6462, 821.17375, 2102.4939, 2203.174, 8003.0345, 3302.8893, 692.98057, 623.0553, 2503.6965, 1298.8223, 616.92084, 5835.5533, 615.4414, 1647.8048, 3880.8935, 13372.708, 666.70354, 639.00137, 710.26074, 1062.0651, 657.45208, 11229.394, 3880.8935, 1023.5208, 925.76837, 8624.2198, 3880.8935, 1783.2075, 1108.5426, 1106.0439, 975.11669, 6662.2447, 6404.207, 724.16104, 1156.4886, 767.30074, 1143.8394, 1203.5484, 4820.2409, 739.27483, 3880.8935, 4781.0435, 657.76936, 997.73811, 747.80745, 675.01153, 972.77302, 3608.6928, 5035.4248, 647.29471, 12624.46, 699.1858, 13618.139, 923.99683, 656.92893, 1673.7603, 623.984, 3880.8935, 3880.8935, 1391.4525, 1597.3745, 881.15178, 3608.6928, 619.17206, 625.7592, 1629.5555, 625.9336, 1431.6131, 2411.2242, 1043.472, 2048.6462, 687.49531, 990.72641, 640.48891, 3608.6928, 1517.8647, 7130.9219, 794.47057, 808.23306, 917.31734, 3593.9705, 696.38448, 646.5681, 629.77742, 649.46169, 3608.6928, 10188.776, 7140.4984, 632.37339, 718.6604, 822.28145, 987.19847, 4453.8965, 656.89161, 615.75973, 7900.4698, 2331.3797, 634.1224, 672.14935, 6880.2593, 764.30545, 679.29064, 1070.9869, 11416.706, 11894.841, 2495.3097, 4300.7568, 1183.0525, 1055.5353, 3608.6928, 2022.2222, 628.34491, 629.66828, 1810.4295, 656.67135, 4858.7501, 1303.5709, 1015.9385, 1062.7261, 615.56093, 8721.2158, 882.69788, 2548.9224, 1496.4222, 775.24099, 1503.9954, 3880.8935, 4188.9692, 811.57407, 5944.3636, 725.08493, 651.36754, 1090.2644, 695.95618, 918.69296, 3608.6928, 654.78149, 1940.4504, 1698.3578, 632.66002, 627.11015, 655.45304, 694.26217, 3608.6928, 856.70344, 839.28954, 829.76872, 3780.104, 923.52487, 1251.9208, 11684.735, 5433.3245, 1360.8119, 4692.9884, 2360.4889, 761.52481, 3880.8935, 907.29613, 2048.6462, 639.58066, 792.93821, 617.70916, 2002.0333, 2052.3499, 876.83901, 1356.3348, 1249.9773, 670.67417, 731.0187, 1575.0058, 2203.174, 2451.0452, 12590.075, 729.28429, 2048.6462, 1260.284, 737.30848, 705.45659, 3880.8935, 633.17901, 9320.0787, 1134.0218, 644.94711, 1399.6673, 908.84677, 3608.6928, 1057.3759, 727.91669, 632.14383, 773.40638, 1316.3017, 2048.6462, 3880.8935, 1724.2837, 1588.0623, 615.90176, 760.26313, 1966.3678, 738.84839, 3608.6928, 1552.9039, 637.77215, 3880.8935, 1469.0921, 637.43207, 1831.0426, 10315.142, 8922.3845, 3880.8935, 2542.4391, 809.40525, 5390.2166, 4445.7136, 1838.5104, 1697.6097, 3200.8076, 1257.929, 1388.8145, 1470.1058, 865.49047, 4789.474, 1896.7789, 7045.155, 650.64828, 972.035, 1138.5844, 763.02825, 620.3796, 2203.174, 2451.0452, 5814.6342, 790.5969, 877.43642, 674.5419, 9464.068, 646.15528, 5316.8921, 13087.23, 11883.373, 4386.6947, 1448.2831, 5252.6419, 916.82108, 2048.6462, 618.77886, 2838.768, 935.41304, 864.16433, 740.60218, 6933.3003, 6962.6942, 8839.916, 875.76616, 1757.8339, 3850.9507, 629.86759, 9972.6033, 3880.8935, 6973.2536, 3608.6928, 2203.174, 954.17991, 615.35363, 3880.8935, 1559.8712, 1064.6413, 1144.601, 2451.0452, 4749.1954, 707.59935, 677.48933, 652.07437, 12467.436, 9432.3507, 642.83588, 11091.34, 3608.6928, 714.48281, 2048.6462, 1039.2043, 880.45821, 2258.9113, 799.53208, 3880.8935, 699.91541, 658.8264, 1157.5185, 615.36038, 4394.209, 615.37361, 666.87902, 666.53256, 630.48081, 630.16926, 693.09397, 640.67687, 993.21697, 689.72937, 2203.174, 624.15491, 914.00278, 615.65063, 935.6642, 1049.6821, 900.17453, 625.92945, 8309.7303, 651.04583, 1467.5835, 622.25191, 693.67247, 2203.174, 677.05527, 7487.1688, 3880.8935, 950.09336, 12646.823, 617.27001, 8558.6174, 1752.2444, 647.92067, 2387.954, 1334.9775, 11861.397, 2637.065, 4267.4049, 1939.4984, 616.5407, 741.72588, 4587.7734, 1802.2427, 1582.467, 1847.1701, 4560.0603, 640.75754, 3608.6928, 3668.6246, 4614.1671, 6567.624, 866.15219, 860.33428, 1212.6905, 702.26359, 13558.679, 854.69588, 10034.145, 13591.37, 615.72088, 3180.8849, 3812.4769, 1002.5638, 836.72669, 955.26534, 617.08973, 624.12799, 12766.417, 3608.6928, 1751.5698, 2686.8449, 10124.779, 716.9458, 13597.696, 1095.0968, 11128.209, 1359.9742, 2473.2929, 3608.6928, 1549.9666, 6562.1119, 5125.8593, 971.464, 1162.4896, 615.90231, 2451.5903, 7893.7726, 7813.3671, 10028.036, 1562.2298, 1105.0782, 3608.6928, 671.01796, 7849.6077, 8201.1965, 2203.174, 644.42162, 9393.7727, 617.64199, 1391.4525, 3608.6928, 682.1132, 618.70277, 3608.6928, 8804.1016, 840.70461, 2035.5122, 1926.7734, 713.14461, 8847.3318, 615.46255, 2508.7651, 8575.3975, 767.10515, 1391.4525, 1471.906, 791.57264, 3608.6928, 621.94415, 10280.981, 2203.174, 1412.438, 981.91051, 3880.8935, 840.92439, 11653.652, 898.41849, 3880.8935, 3880.8935, 815.87871, 13524.457, 801.63335, 1653.7276, 1262.4596, 3608.6928, 1255.4725, 650.87377, 1340.6947, 670.79926, 1596.9046, 1287.0511, 921.51954, 3880.8935, 4490.0676, 769.40901, 3608.6928, 671.49374, 750.76689, 1216.1064, 13567.512, 2203.174, 9145.0038, 1380.3705, 6269.2732, 679.529, 643.95579, 1362.859, 3608.6928, 4301.7379, 13166.681, 11559.482, 1062.256, 961.73267, 9425.2752, 2447.7122, 766.9472, 631.36114, 1371.5295, 4563.5834, 3880.8935, 624.89129, 1318.0014, 5625.3858, 844.93309, 644.65323, 615.47204, 669.03462, 1371.8173, 3608.6928, 2431.1107, 2149.9912, 627.84246, 2404.2304, 797.81877, 2162.3108, 782.87624, 12268.553, 1526.3151, 934.61074, 3880.8935, 878.8124, 727.84354, 2127.9036, 616.28322, 1989.1882, 636.52996, 2048.6462, 617.91966, 1391.4525, 668.74269, 932.1524, 3608.6928, 665.20636, 625.25163, 12612.217, 3966.2858, 11877.964, 631.53333, 1329.8064, 7762.8931, 635.28038, 11917.111, 8092.3258, 1106.9253, 5714.4069, 13034.96, 722.54671, 10277.467, 1986.2447, 3608.6928, 6353.1936, 6341.1148, 632.45431, 3966.3272, 619.60188, 799.37852, 986.87678, 5452.6494, 759.99169, 3027.8181, 2085.0158, 3880.8935, 7399.8222, 3450.1169, 5005.2872, 13530.974, 1292.7038, 664.96569, 616.12496, 772.72082, 650.05737, 2834.6427, 3676.1769, 2040.6778, 782.74241, 3880.8935, 936.09249, 1538.5838, 615.35306, 1210.1865, 6746.2929, 1022.2657, 1772.4977, 1187.0541, 8845.415, 629.67096, 6967.1553, 13375.352, 13601.141, 2048.6462, 710.31571, 4646.5735, 1657.1894, 625.5818, 616.3636, 692.91939, 2203.174, 2525.6176, 13056.414, 747.66353, 615.72668, 2383.487, 3608.6928, 2451.0452, 1425.412, 5094.0578, 5466.9166, 9216.7311, 2048.6462, 2203.174, 13143.234, 1702.2251, 2203.174, 926.54522, 694.1251, 690.28605, 3608.6928, 683.00806, 3608.6928, 1536.4948, 711.06602, 11130.383, 703.13024, 1537.0019, 1565.0497, 13061.934, 621.00532, 946.30209, 9688.6596, 747.34063, 1049.3907, 621.38782, 2048.6462, 2451.0452, 624.84046, 4202.4348, 926.53871, 3880.8935, 975.35587, 5816.6209, 1356.4458, 705.73866, 2888.9782, 645.68116, 8416.6604, 9493.8426, 12649.152, 757.2332, 615.99158, 11484.716, 930.77596, 866.15831, 4086.7448, 4701.2803, 661.75975, 2203.174, 2203.174, 2203.174, 1509.7642, 621.64402, 1096.4446, 3199.4025, 675.88909, 3972.5039, 2451.0452, 12085.037, 3608.6928, 1615.1118, 1070.1684, 9209.9291, 1100.4302, 3067.9503, 1043.4774, 3880.8935, 624.48907, 1161.467, 1255.8581, 2048.6462, 3047.9417, 9258.5986, 1614.4871, 626.29215, 8462.9798, 649.14565, 1077.7536, 5980.4447, 7268.1878, 790.84498, 760.0364, 1800.9468, 1438.5169, 651.24892, 5536.6108, 617.05156, 1772.1354, 2175.7726, 637.29342, 1519.7555, 3511.2253, 6073.0559, 792.23176, 8816.5767, 820.41097, 798.78448, 876.3944, 635.01883, 3527.8813, 2480.9839, 722.97992, 1293.4387, 1273.6726, 2612.1501, 1154.2686, 937.7426, 12462.649, 761.70233, 2451.0452, 2213.5008, 10998.158, 2407.8961, 12731.47, 2381.007, 11145.311, 617.4118, 617.17189, 638.35552, 1089.8847, 1431.7925, 2048.6462, 9557.8945, 615.35553, 1102.2466, 1904.5744, 684.57101, 5316.5792, 897.09897, 3491.5051, 616.57176, 759.45895, 1823.1721, 2203.174, 617.54832, 1213.317, 2298.839, 884.35097, 635.10091, 2886.1864, 714.16999, 880.21615, 801.11293, 1894.6652, 740.68173, 7426.8903, 639.98103, 641.95028, 2048.6462, 718.02288, 1519.5815, 1066.1118, 1571.0062, 3608.6928, 649.51915, 6901.5869, 1273.059, 684.33754, 627.16408, 651.72993, 781.77924, 13200.674, 6669.8015, 621.57396, 7464.8943, 1148.2909, 5970.1903, 13541.462, 615.35398, 2386.6627, 884.94611, 616.79824, 3608.6928, 624.24502, 3608.6928, 675.30161, 2972.9528, 1066.3156, 745.38706, 665.02522, 1179.912, 9237.7695, 624.59892, 3291.3045, 926.04269, 3608.6928, 11530.36, 648.85978, 622.59251, 3608.6928, 1273.1934, 2203.174, 2203.174, 10170.557, 8311.3159, 705.32554, 860.19222, 5030.8439, 11405.357, 2085.1714, 999.3624, 3106.7102, 2048.6462, 3608.6928, 616.08629, 748.83192, 963.73648, 804.30047, 3608.6928, 700.13825, 1188.6645, 1786.9691, 1803.1994, 12902.439, 11771.339, 6703.3693, 640.87427, 664.84421, 681.58495, 643.39236, 2048.6462, 680.45878, 11467.267, 2451.0452, 622.75736, 735.29188, 6119.3419, 918.83316, 722.82757, 2717.4593, 11872.807, 1920.6243, 2516.7407, 743.26604, 9103.031, 656.82417, 2048.6462, 13363.785, 674.73365, 4115.3866, 1707.5289, 2203.174, 683.10766, 9629.2418, 12669.381, 1508.2907, 700.62928, 9834.9385, 3529.9611, 2048.6462, 4936.1551, 615.36088, 621.07595, 747.91701, 1445.0394, 1856.3988, 1580.1258, 2203.174, 1958.8589, 615.52082, 1579.11, 617.25133, 13428.636, 12455.391, 706.16499, 1199.9311, 1593.0523, 3608.6928, 2395.1133, 3787.0785, 6910.4891, 3608.6928, 665.21403, 5607.0256, 4379.8224, 965.78346, 653.98209, 655.06358, 875.14107, 850.87198, 880.81097, 3410.6458, 935.47902, 3075.3536, 1391.872, 617.51109, 709.21899, 4314.1643, 3608.6928, 3880.8935, 2021.3344, 634.34546, 9376.853, 655.76258, 10031.101, 4406.7808, 952.39408, 643.10896, 622.73886, 647.12105, 1199.5687, 931.40729, 1054.6994, 622.47432, 897.45601, 1734.0945, 1293.3155, 2148.9082, 617.30959, 706.82932, 647.46257, 621.37211, 785.77009, 618.74003, 816.00638, 11745.409, 5332.4244, 629.47879, 2069.4014, 2203.174, 8669.6556, 696.68215, 1868.2902, 896.41946, 627.74126, 627.89033, 10570.581, 2048.6462, 842.13714, 863.89445, 633.76913, 4192.1887, 2125.7193, 632.79355, 1993.1352, 5860.3878, 1179.6444, 664.13027, 1000.3859, 937.02164, 817.17682, 7498.37, 3608.6928, 2236.2594, 3608.6928, 2048.6462, 639.29352, 853.84368, 3608.6928, 699.93745, 624.23402, 3371.097, 3608.6928, 2203.174, 1841.5042, 12117.346, 2137.9162, 712.39092, 1568.3386, 627.62618, 636.49695, 621.54451, 12857.775, 636.94117, 1060.4774, 896.1632, 704.56389, 692.76931, 1864.0647, 7530.0869, 669.17574, 2203.174, 1354.9633, 621.88059, 2048.6462, 1921.7281, 659.63501, 882.38346, 620.10586, 779.54127, 818.75829, 772.68005, 929.70752, 3608.6928, 2179.0819, 637.03023, 698.66565, 1629.9827, 777.19441, 864.05347, 13472.649, 3313.9836, 621.16979, 1597.0783, 7719.0169, 865.9359, 902.31851, 1174.7462, 761.96327, 623.60333, 658.92264, 3961.2076, 788.73546, 1680.8241, 1238.9794, 1619.3318, 1261.2574, 2272.2236, 687.80078, 4781.9891, 3608.6928, 1837.3741, 1752.6707, 2048.6462, 628.52982, 13380.51, 2017.155, 3608.6928, 634.58619, 649.77502, 829.01371, 8483.8511, 691.92891, 1114.6625, 942.84733, 2345.7942, 728.74909, 5520.5592, 11577.663, 2048.6462, 11128.928, 1026.717, 653.25486, 615.4529, 616.86654, 13429.651, 874.87504, 620.22574, 8833.0123, 3608.6928, 3608.6928, 774.2981, 3608.6928, 3205.7025, 739.61681, 11342.115, 688.01507, 823.67614, 633.71771, 665.73922, 1317.8103, 13066.512, 6218.1514, 9138.185, 646.69326, 1437.586, 768.1812, 5089.9846, 12745.099, 3681.6565, 631.79665, 905.45403, 1275.3661, 3608.6928, 763.07963, 3608.6928, 835.45161, 3181.2002, 2451.0452, 619.84656, 5535.706, 616.7852, 7029.5295, 615.68193, 615.615, 6492.3892, 2203.174, 984.78153, 13582.118, 12979.201, 615.40999, 1076.5734, 1121.972, 764.66938, 846.75942, 5442.7033, 877.91136, 2203.174, 3482.9234, 645.80354, 617.1706, 635.31243, 2177.034, 4826.0924, 660.20047, 698.61869, 639.58727, 615.46609, 788.24883, 635.88085, 688.1804, 810.98992, 2451.0452, 945.60149, 2048.6462, 1036.893, 864.82703, 4909.6928, 2071.3688, 13473.369, 10227.198, 626.96036, 2203.174, 2048.6462, 7478.5558, 4251.9246, 1250.907, 6687.5206, 1005.5352, 2162.3278, 695.68595, 1285.8848, 615.67747, 6374.139, 3608.6928, 622.69876, 2451.0452, 10760.243, 13075.33, 839.27918, 647.75178, 5989.2426, 2203.174, 3794.7637, 2227.761, 11855.594, 3880.8935, 918.95673, 3880.8935, 12819.545, 2451.0452, 13575.962, 3880.8935, 2451.0452, 1416.4705, 1064.7769, 977.09934, 2048.6462, 5379.534, 1100.6789, 717.28848, 1878.5998, 4829.2172, 2203.174, 5485.3445, 615.57161, 11756.52, 630.48859, 3880.8935, 2048.6462, 810.93717, 810.77113, 3608.6928, 2451.0452, 3880.8935, 909.12907, 3608.6928, 908.99787, 2203.174, 686.13706, 2048.6462, 2203.174, 775.25564, 753.33495, 3880.8935, 5239.8711, 13124.766, 669.40692, 1034.4058, 11882.35, 1868.7412, 853.37972, 11102.453, 4050.3546, 680.33739, 616.98687, 13618.218, 706.1326, 1640.4033, 8609.5246, 657.40966, 9571.513, 974.23304, 2203.174, 4768.5514, 10867.338, 702.31121, 7061.4066, 837.12754, 12659.71, 3880.8935, 3608.6928, 3720.5053, 3880.8935, 632.78553, 3680.3791, 4649.452, 1391.4525, 628.77631, 703.61393, 752.36982, 646.7327, 1181.4366, 615.4521, 1639.3124, 618.61992, 616.52057, 13525.236, 2048.6462, 6139.0908, 1488.3819, 724.91439, 917.25689, 973.46397, 13518.534, 644.20761, 618.22647, 3608.6928, 627.94271, 1783.456, 616.22135, 969.58372, 2048.6462, 725.00964, 634.3211, 694.09619, 635.24995, 691.65011, 1257.867, 2848.9299, 2138.944, 687.76851, 2203.174, 1277.7248, 6961.4526, 950.10482, 2451.0452, 629.21314, 622.89775, 656.9358, 676.85264, 1123.8611, 1779.8999, 1448.2014, 1243.8062, 4472.1483, 3880.8935, 2203.174, 3880.8935, 9555.1114, 646.42941, 615.73811, 748.97839, 1376.9385, 1269.6102, 2048.6462, 1792.6851, 663.67239, 5812.7774, 1712.3072, 4814.3616, 870.22299, 747.89811, 1293.0288, 639.27339, 12673.323, 11452.312, 10752.171, 11879.264, 9411.2364, 2048.6462, 2203.174, 963.95168, 1676.0401, 944.6902, 820.57559, 637.68902, 4709.7311, 1523.6279, 2061.4307, 2263.5554, 615.78855, 617.90427, 1040.5778, 2203.174, 2048.6462, 623.86617, 672.4344, 701.69385, 3880.8935, 4425.2561, 714.55477, 720.19549, 935.07005, 615.35486, 2048.6462, 649.4169, 1254.3191, 7210.1265, 821.82825, 10292.87, 1419.2649, 3880.8935, 3608.6928, 768.0438, 12281.738, 1583.7447, 2203.174, 2048.6462, 5463.6126, 685.18423, 12852.326, 672.87694, 1329.083, 2203.174, 1051.6155, 693.85931, 1324.73, 628.42977, 1297.211, 2064.5422, 1440.4452, 2941.1178, 2203.174, 642.8161, 646.21351, 2468.9135, 615.49615, 13533.714, 10480.89, 3608.6928, 769.64444, 2158.8946, 9536.0055, 1185.7316, 1802.4547, 3507.7555, 3608.6928, 1252.0983, 4273.5284, 664.82186, 2541.3577, 864.94477, 1259.5434, 686.68651, 1524.2368, 720.53104, 2907.3521, 2452.3157, 648.58606, 3252.133, 1365.0581, 873.03652, 688.84032, 1404.1373, 627.31386, 667.09343, 616.6211, 5297.6549, 1425.4015, 687.86382, 8497.0994, 651.86698, 1207.3768, 5699.6642, 615.49091, 1260.0446, 3834.4191, 717.8502, 620.32897, 3608.6928, 781.23897, 655.70415, 3031.9525, 929.2233, 10655.621, 4808.1589, 1070.565, 10153.596, 686.539, 6213.0452, 1252.8339, 664.99245, 3608.6928, 6543.2098, 4905.8609, 10413.256, 1735.8682, 11100.621, 1038.6046, 2203.174, 2016.9807, 2352.9626, 3866.4839, 783.36935, 759.43669, 1595.2774, 663.1757, 3815.8629, 1469.321, 615.50999, 769.55846, 2104.4832, 890.46341, 637.61149, 3880.8935, 704.075, 1917.6576, 4085.6613, 7636.5841, 618.36458, 2232.8507, 1043.1045, 13465.466, 797.96079, 854.44537, 2048.6462, 6060.4242, 3608.6928, 628.37402, 1587.7669, 711.10436, 638.14677, 3608.6928, 765.94004, 3880.8935, 13471.55, 7224.6331, 11939.191, 3830.0575, 756.15583, 734.35853, 4533.1848, 4571.2115, 685.16873, 1186.3647, 616.10457, 13592.233, 672.6819, 636.66957, 1387.6634, 1683.0454, 1074.9601, 2203.174, 12760.283, 9206.473, 784.94879, 1359.2228, 628.58804, 828.15344, 621.27572, 626.24362, 12988.384, 1414.8257, 3608.6928, 2381.6955, 3576.4026, 13548.643, 660.82684, 3880.8935, 2048.6462, 695.31495, 950.78083, 11249.022, 808.20276, 3608.6928, 629.49791, 3608.6928, 966.44101, 2552.1811, 769.79682, 692.31877, 4370.0161, 1155.4945, 661.72904, 734.54337, 1949.8671, 3265.3327, 721.22204, 1788.6235, 3608.6928, 5806.5096, 3880.8935, 870.76067, 1420.7323, 1119.0016, 4888.8912, 2211.2085, 11901.173, 618.53423, 734.33957, 798.58619, 618.16128, 904.03896, 734.61931, 678.48951, 813.65195, 680.56167, 10194.632, 3880.8935, 2048.6462, 710.3688, 7168.2265, 10679.48, 628.47381, 3624.2155, 3608.6928, 706.50716, 11473.243, 747.22357, 3608.6928, 702.29068, 3880.8935, 629.11591, 3608.6928, 1327.4275, 940.72359, 11236.864, 978.87985, 3608.6928, 13547.662, 1613.6533, 5027.0273, 3608.6928, 703.52037, 3608.6928, 7801.0704, 778.82532, 2451.0452, 665.92562, 3608.6928, 2203.174, 3608.6928, 617.87208, 1849.5031, 956.6553, 1014.2342, 13613.555, 790.95244, 631.58734, 13013.161, 687.05393, 1132.558, 615.98223, 2451.0452, 841.0331, 1818.1852, 617.9599, 667.50228, 879.41239, 621.99039, 1336.3291, 2594.8151, 1391.4525, 1273.9843, 655.41145, 10533.825, 13434.114, 615.4925, 3608.6928, 1395.9835, 12020.234, 8459.0944, 4824.1037, 979.62288, 2203.174, 1253.9982, 2669.8072, 641.19036, 632.23788, 3608.6928, 7429.0762, 3494.4434, 1150.7762, 679.03478, 2048.6462, 676.45407, 4741.5634, 2465.1494, 9253.6844, 3417.6062, 1057.1892, 759.77236, 1088.9189, 909.69331, 1008.4123, 674.61793, 13554.861, 9489.5964, 1899.5466, 2192.3364, 3880.8935, 9533.6792, 7149.9716, 5331.1543, 12869.451, 2089.3356, 809.08196, 615.35274, 678.28141, 1729.4436, 696.81076, 663.67457, 3608.6928, 3880.8935, 10487.846, 621.45696, 2285.6002, 2294.2142, 824.43671, 616.16103, 618.37799, 11027.408, 2640.5929, 7568.2734, 3105.7772, 653.30423, 3069.3821, 650.90014, 3608.6928, 1300.7132, 907.12921, 744.89428, 1068.1604, 1690.1227, 786.75933, 3608.6928, 618.12612, 3608.6928, 617.09733, 1003.2728, 1861.4201, 1174.8705, 11484.091, 3748.5009, 826.54903, 615.37865, 4638.2041, 616.77121, 3608.6928, 2203.174, 803.03799, 2360.4813, 645.30392, 697.40976, 3880.8935, 730.66791, 929.25817, 3880.8935, 692.12301, 3678.2345, 11801.162, 2243.2905, 5405.9945, 1218.6066, 1393.8789, 699.27171, 942.53152, 2153.3531, 681.27178, 667.09017, 677.80766, 616.86023, 4730.5983, 8821.7348, 1791.5241, 809.03287, 1032.2232, 653.77347, 1337.8329, 2284.1125, 1001.8079, 3940.4193, 617.44424, 773.57852, 635.01829, 11048.536, 639.87388, 1298.4501, 3608.6928, 616.73265, 3737.8289, 1012.7156, 2451.0452, 977.15916, 704.20564, 642.91536, 701.49534, 4691.8639, 1745.4519, 2457.503, 915.14446, 1161.383, 11675.676, 659.56834, 4486.3771, 634.09228, 2203.174, 917.85398, 6185.1901, 951.89745, 4771.1087, 2936.8557, 2328.6986, 1647.0449, 619.55919, 3059.172, 2463.1259, 2451.0452, 1275.8768, 9412.565, 1814.5118, 5690.3683, 633.89199, 8904.0034, 13617.608, 3608.6928, 1521.9208, 3587.0261, 645.73969, 634.12545, 656.99742, 1351.7109, 649.4301, 5548.1655, 3880.8935, 2203.174, 2555.6524, 3880.8935, 1346.4119, 1430.5078, 1261.0575, 668.42991, 7419.1369, 1166.339, 5402.4235, 966.48653, 615.5539, 634.87798, 1800.3805, 6627.0605, 748.92784, 925.54673, 1391.4525, 3608.6928, 2048.6462, 7232.796, 3880.8935, 725.36518, 629.52046, 8324.8275, 2203.174, 671.68136, 7747.8458, 654.36467, 1497.938, 734.67367, 623.55893, 1678.3056, 5493.4748, 636.01742, 707.1412, 1861.6229, 2541.8109, 616.54792, 1360.8611, 2203.174, 640.60303, 2211.0575, 669.87206, 5306.6048, 1492.2906, 625.06984, 921.6905, 660.61245, 7253.9355, 949.0631, 5240.4671, 701.56726, 958.3959, 13562.202, 2449.6181, 1572.2128, 7935.0857, 2203.174, 722.38026, 7660.4856, 2728.6748, 876.41181, 726.91911, 10701.771, 782.99296, 1103.618, 2451.0452, 670.96734, 750.05914, 3880.8935, 1890.334, 619.3818, 12574.22, 3880.8935, 12753.244, 5081.4662, 773.87168, 13095.543, 672.51487, 814.87231, 980.05547, 3893.6959, 708.90459, 2909.8403, 652.08364, 3880.8935, 616.43191, 652.85529, 4536.3505, 3880.8935, 2390.254, 3880.8935, 2048.6462, 739.74398, 899.84231, 2373.7937, 933.0601, 782.90947, 1547.8802, 983.14692, 647.78319, 891.54421, 13414.315, 689.28418, 656.01352, 714.04756, 13596.334, 3880.8935, 7080.0154, 640.25208, 654.4429, 9227.7863, 2001.6815, 3772.7166, 902.99138, 1140.8678, 3880.8935, 12127.101, 841.04366, 664.75793, 623.57828, 620.36407, 1591.266, 11331.375, 617.62929, 11706.822, 11002.355, 11486.961, 11048.767, 632.17979, 1472.9533, 659.63413, 2203.174, 7791.2416, 811.90293, 717.00418, 977.98888, 1605.6772, 8608.4337, 6125.4103, 1411.0495, 664.98755, 687.38999, 1161.2385, 2230.4492, 1635.1916, 3608.6928, 1745.0318, 1420.7488, 3087.1367, 646.59636, 922.26444, 865.86999, 630.24129, 755.57937, 616.47491, 1095.1766, 852.95147, 1367.5624, 3608.6928, 2203.174, 661.36117, 655.30579, 11816.55, 725.36829, 2611.5439, 1179.6224, 2203.174, 848.63798, 3730.8298, 2048.6462, 2996.5662, 1410.2948, 11597.052, 5494.2293, 852.31801, 732.23112, 665.54877, 1999.2273, 1161.1301, 10244.591, 630.62052, 3128.1016, 10797.536, 677.87336, 2048.6462, 2048.6462, 644.59356, 840.09262, 2048.6462, 9566.1416, 2261.7629, 679.98176, 1714.3553, 3608.6928, 943.02299, 11799.543, 9716.6633, 8190.0732, 3880.8935, 6799.3957, 1252.0958, 2967.4614, 1073.0141, 749.328, 1301.1661, 701.95579, 7752.4972, 1388.7936, 877.31104, 1768.7771, 6601.8471, 6973.0746, 2048.6462, 13425.863, 8378.5479, 9802.9423, 2541.3371, 7572.378, 2817.33, 13580.037, 1267.0855, 13441.286, 617.82012, 4341.9249, 865.8641, 707.17475, 715.96059, 6550.4902, 800.28391, 1882.8564, 744.26921, 2124.027, 11299.377, 725.37724, 633.19479, 712.83507, 2203.174, 4579.0113, 2048.6462, 649.01999, 621.32082, 1434.5342, 6438.2833, 641.26194, 871.12962, 8086.2241, 2739.9398, 3608.6928, 680.82704, 13174.445, 734.96946, 929.09676, 624.51014, 2203.174, 9701.6347, 902.01291, 4594.3921, 700.07958, 8315.1516, 1454.8009, 679.95257, 13583.661, 1235.205, 3246.4579, 1225.5249, 618.42974, 615.35472, 7205.1887, 1143.6878, 615.88893, 641.07192, 623.91225, 4247.0987, 1044.8272, 9027.1115, 784.43777, 1936.4932, 9040.5908, 1991.0908, 823.01914, 633.75359, 628.28659, 635.30907, 7775.7435, 615.36889, 11378.696, 794.50245, 4720.1463, 3608.6928, 2048.6462, 13415.452, 2203.174, 2203.174, 659.04842, 5725.5182, 1203.1877, 617.00395, 2476.2206, 4725.6652, 682.0942, 12261.253, 1269.3799, 5115.3733, 8083.9015, 7464.2306, 6269.9067, 1103.6525, 1863.7124, 620.06981, 13327.029, 714.49835, 701.60259, 825.05589, 1382.7186, 768.0088, 925.56069, 3880.8935, 615.42163, 676.72784, 1289.7049, 1323.7398, 3095.1906, 1006.2391, 3792.6793, 9744.0373, 3608.6928, 813.78213, 10300.08, 662.2954, 3150.2751, 2203.174, 627.17209, 3502.9085, 3608.6928, 10540.956, 641.54813, 11976.168, 6623.8132, 3880.8935, 619.89537, 3824.9859, 2203.174, 1200.369, 2090.3037, 665.41001, 681.66168, 2203.174, 2982.644, 793.00583, 12616.717, 1355.0862, 2203.174, 659.76702, 691.33912, 639.78435, 5342.5632, 746.38285, 3447.8829, 2438.8397, 662.68492, 1051.5072, 2451.0452, 622.70734, 3632.9145, 5127.5979, 2354.1487, 1323.094, 1165.8689, 717.53851, 6667.7072, 11688.721, 675.50215, 3880.8935, 3880.8935, 1358.5181, 1259.9155, 13164.456, 9127.1005, 3880.8935, 875.01725, 3898.1499, 6974.6728, 3956.6339, 615.47076, 3608.6928, 12401.307, 955.86224, 13617.057, 792.64638, 1879.2529, 1407.031, 4410.7732, 2426.2106, 664.38136, 3880.8935, 1157.5965, 694.30185, 3608.6928, 1786.0744, 2048.6462, 634.75411, 618.72919, 3608.6928, 623.36075, 764.84311, 1406.7126, 6570.1937, 616.48986, 13562.682, 1472.49, 829.00707, 10136.021, 698.38622, 641.50339, 664.00074, 2475.1019, 2564.551, 936.71393, 615.57544, 9866.4877, 618.5883, 966.34897, 659.12361, 3442.075, 5499.7146, 4914.7218, 788.06041, 1541.7595, 3608.6928, 647.31728, 1031.9847, 2048.6462, 11571.576, 2018.0921, 877.66157, 3990.0173, 1341.1599, 1480.0018, 8393.1552, 2413.251, 12403.22, 1938.4293, 619.0661, 621.00413, 1302.1518, 3880.8935, 909.64897, 6809.2365, 2271.2877, 1167.6442, 4253.0252, 1391.4525, 617.97193, 1187.148, 633.95644, 3608.6928, 1576.8311, 8405.5631, 3880.8935, 13084.364, 650.1589, 695.33381, 620.68861, 648.53785, 7869.269, 1947.3505, 836.96461, 6036.6217, 626.39423, 4876.5457, 3880.8935, 3608.6928, 629.68709, 824.04611, 637.89311, 664.03961, 615.40776, 2153.7515, 7071.0763, 11650.403, 681.61594, 1110.7978, 5158.6367, 888.81156, 1226.9322, 3608.6928, 754.59001, 4320.88, 9215.7099, 2048.6462, 2313.6634, 617.7299, 662.61863, 617.26549, 3880.8935, 890.84466, 746.58116, 637.91807, 9984.4536, 681.81204, 709.52485, 670.60506, 816.7837, 5534.3546, 8740.2229, 645.20822, 927.96824, 5403.3806, 1738.6178, 2048.6462, 630.65564, 670.366, 1411.5258, 1405.2873, 3982.2153, 698.83292, 3880.8935, 1202.8796, 884.03683, 1744.2068, 780.38857, 689.55927, 638.38247, 2230.0695, 3880.8935, 5907.7836, 3608.6928, 872.31321, 7076.0625, 4600.6305, 719.59565, 3608.6928, 2055.2543, 685.42323, 631.94831, 1947.9029, 645.95745, 3608.6928, 622.09357, 706.01766, 1203.3807, 3033.0764, 12764.332, 2402.3797, 733.26889, 1036.6389, 628.3089, 620.78381, 6910.1554, 3880.8935, 687.50251, 3562.0595, 1404.4402, 13335.645, 1551.9866, 3880.8935, 710.19384, 693.09893, 2048.6462, 936.67232, 3608.6928, 661.8167, 626.9804, 3608.6928, 4608.7589, 914.40129, 634.62786, 3608.6928, 3778.1986, 645.63722, 621.30323, 2048.6462, 6369.2449, 663.30465, 1631.8189, 6481.6886, 864.43422, 862.43662, 618.90668, 616.86934, 740.66933, 817.48424, 1046.5214, 1773.0215, 641.73248, 2451.0452, 825.29194, 3880.8935, 793.58478, 666.8366, 1183.825, 726.84584, 615.40082, 9299.3253, 1406.6324, 764.85509, 2451.0452, 3699.8575, 2048.6462, 624.42948, 1322.4406, 926.99386, 996.87606, 1126.4828, 3608.6928, 2048.6462, 963.01948, 615.55613, 982.64, 626.24109, 636.57917, 1762.7905, 12722.434, 5959.7799, 1487.9513, 2785.0238, 1100.4053, 3694.2862, 747.43505, 3608.6928, 5135.0877, 1014.233, 6036.9652, 759.32907, 2240.6794, 839.60793, 1975.0365, 3608.6928, 619.81652, 3482.787, 1600.632, 615.83016, 681.32725, 13617.418, 832.98814, 13527.268, 2342.3301, 615.38838, 1355.4499, 842.48722, 2203.174, 636.02256, 2203.174, 646.12678, 3880.8935, 623.6467, 2451.0452, 5423.8508, 13618.214, 960.45716, 615.75179, 753.28619, 2203.174, 6131.2707, 4227.3919, 2203.174, 616.36559, 3608.6928, 5708.7994, 967.92601, 819.10263, 3777.6256, 5535.6146, 882.44697, 9013.1487, 4779.6703, 5479.4754, 1542.9376, 643.26083, 774.94078, 890.47081, 3880.8935, 2203.174, 1058.8579, 2280.303, 1106.4237, 642.46109, 11743.167, 678.90185, 7624.0929, 1453.608, 12235.484, 1269.8642, 707.46349, 8708.8462, 11171.781, 617.81939, 7401.983, 3880.8935, 1273.8663, 6856.2707, 1067.2495, 1106.5566, 819.09275, 974.41526, 617.353, 3608.6928, 812.11152, 3913.9439, 3880.8935, 1181.0542, 837.38412, 6853.9661, 3965.3401, 1205.6646, 621.9474, 671.6071, 630.88253, 7654.1942, 616.54077, 633.52235, 2203.174, 810.70266, 679.65962, 3880.8935, 2048.6462, 12989.481, 2196.2855, 615.46795, 678.20747, 2203.174, 3430.7525, 942.09656, 698.49586, 1166.9866, 3608.6928, 1280.7719, 615.56241, 3639.1525, 1753.624, 1391.4525, 628.42193, 634.88281, 3608.6928, 3880.8935, 2084.7416, 1969.451, 2048.6462, 2065.5467, 733.2875, 13559.315, 1263.3134, 2243.429, 617.8966, 651.38353, 1617.2797, 3369.2434, 2451.0452, 1055.1491, 800.00475, 1668.3668, 7311.7923, 3608.6928, 3608.6928, 1429.8638, 920.50404, 646.72195, 3608.6928, 704.60001, 688.0199, 10582.149, 617.78962, 669.07145, 714.15378, 863.68483, 1104.9805, 3880.8935, 3557.5201, 2451.0452, 11384.288, 2189.7977, 720.1959, 2203.174, 6211.0849, 626.85805, 962.70328, 1014.4509, 840.5744, 808.85957, 726.45232, 1126.9643, 796.85115, 639.12869, 2767.7436, 4565.7602, 1311.2856, 5361.6468, 3608.6928, 796.5888, 733.77866, 2048.6462, 617.25918, 7350.4312, 6301.6044, 709.64246, 1454.095, 1391.5051, 658.50938, 631.93802, 1129.3653, 1412.0513, 3630.3895, 630.38359, 13353.956, 3880.8935, 728.39447, 622.80169, 2203.174, 676.8186, 4307.9428, 1775.6515, 2713.9972, 13210.933, 1103.3549, 702.36872, 641.48571, 1002.8991, 647.49883, 658.83377, 5102.5927, 2451.0452, 3880.8935, 5698.5391, 1219.0461, 3689.6187, 679.89931, 615.35366, 802.31065, 1399.0397, 6365.498, 615.44395, 2203.174, 1435.7913, 722.06529, 2048.6462, 3759.608, 12656.387, 872.64985, 670.28742, 2203.174, 2048.6462, 13426.701, 690.52228, 616.06027, 1332.0648, 792.26891, 11471.96, 11987.268, 663.1018, 13268.052, 2048.6462, 2203.174, 5284.6623, 695.31951, 628.36977, 12549.068, 3880.8935, 6712.3383, 2128.3433, 2701.6096, 633.37699, 2048.6462, 900.54904, 1000.2394, 1060.7919, 641.5619, 1238.0457, 630.1344, 615.60391, 1159.4114, 957.19701, 3608.6928, 2203.174, 682.89975, 742.32731, 2429.4306, 843.28577, 650.46205, 626.14664, 644.40908, 649.33098, 669.0232, 1229.5052, 5773.0296, 8343.6686, 1890.7607, 13451.335, 2139.1195, 707.2377, 11738.59, 1096.0874, 819.39936, 2203.174, 683.3411, 810.01355, 642.73509, 1180.4054, 1299.8556, 1762.5951, 1818.7608, 7046.6704, 839.73985, 3645.6477, 1287.2969, 1573.6141, 929.03624, 11662.247, 5002.6011, 3880.8935, 885.7005, 3043.215, 3388.2752, 2451.0452, 631.96423, 681.16454, 881.79304, 3880.8935, 3723.0017, 2256.4441, 615.94094, 5943.4517, 7157.6946, 898.19674, 629.10341, 781.50694, 3880.8935, 659.35404, 11670.489, 7684.5069, 914.13277, 615.47101, 623.94039, 1078.8581, 2203.174, 1744.6716, 823.82312, 4623.4718, 3608.6928, 3608.6928, 679.9819, 873.40384, 1461.8655, 2203.174, 776.43573, 13508.68, 12857.794, 616.35276, 958.8152, 670.01017, 1388.7589, 632.58924, 3880.8935, 12626.777, 1049.1865, 1996.9307, 736.37183, 656.73071, 741.243, 1391.4525, 916.9793, 2048.6462, 638.80539, 4131.1241, 824.17656, 1569.6252, 3608.6928, 7861.3749, 628.20595, 693.08756, 659.96186, 2509.0329, 660.03762, 1453.4394, 732.4977, 5367.8783, 615.95114, 3880.8935, 1886.2284, 793.83865, 653.99405, 11427.651, 2451.0452, 9253.6743, 2074.1605, 2058.5797, 9824.7845, 621.34597, 3514.1579, 1787.0059, 669.15605, 739.59538, 1083.0957, 1983.2312, 679.6812, 1399.264, 7182.5442, 615.43095, 912.32157, 868.3672, 798.81365, 665.23461, 865.31491, 2203.174, 6872.5792, 683.86429, 616.26162, 615.71907, 958.99383, 659.536, 648.43613, 668.6078, 2203.174, 1800.6243, 2013.5361, 10625.651, 2178.8531, 689.38247, 1226.2934, 740.72584, 2048.6462, 725.06645, 1681.6257, 4229.9303, 5965.96, 741.42464, 626.98983, 759.13662, 1381.9256, 1054.9777, 2048.6462, 9451.0413, 756.69381, 3608.6928, 3880.8935, 3880.8935, 1017.4135, 10321.705, 665.44419, 628.502, 1015.0895, 1498.2709, 2582.8505, 12793.858, 11188.383, 895.52139, 635.32301, 2048.6462, 627.61185, 3880.8935, 2048.6462, 2048.6462, 1856.5314, 1483.5549, 678.58058, 916.51797, 616.13839, 2429.5973, 13506.987, 1087.3747, 856.68191, 1845.8594, 617.48456, 1314.823, 689.63832, 1092.0178, 10185.509, 8482.5148, 2638.0031, 2048.6462, 1472.0473, 616.42254, 1313.2823, 1928.3995, 960.48512, 819.75455, 820.5962, 701.56894, 3880.8935, 1025.3029, 620.41838, 2074.8844, 685.92195, 13040.891, 11755.95, 690.07309, 674.77753, 2181.7012, 630.69583, 992.40707, 1005.0447, 615.36661, 7955.7118, 1915.671, 673.13123, 727.41873, 901.9974, 4267.2357, 1182.6864, 740.33765, 694.0655, 5883.785, 631.31257, 11017.023, 627.54835, 3673.6021, 3641.8612, 3608.6928, 903.92806, 1165.6492, 781.54351, 13356.366, 1232.6899, 901.76048, 6166.1598, 1706.571, 1516.8907, 3608.6928, 1424.5878, 975.94349, 1444.0249, 3838.6353, 5328.4871, 7348.312, 3880.8935, 1010.2386, 7991.7806, 615.56769, 4664.7454, 4741.8446, 1208.2569, 3849.9523, 2139.2242, 3880.8935, 1192.365, 2203.174, 3608.6928, 618.07244, 646.91702, 669.74683, 1585.1096, 1664.6127, 623.87336, 863.91627, 3880.8935, 7322.7501, 630.36264, 4186.1076, 761.353, 650.43348, 751.61569, 1035.815, 707.25545, 811.79889, 3880.8935, 673.8395, 697.62384, 621.80056, 669.44882, 2203.174, 2111.1983, 1592.6056, 4161.5852, 1058.9432, 1539.7933, 683.93915, 622.42625, 5685.7703, 682.12796, 10189.945, 5502.8143, 616.96213, 2508.3274, 816.37601, 992.60431, 989.59509, 3608.6928, 12522.242, 992.85252, 13422.405, 1853.1448, 2210.7244, 3880.8935, 619.91769, 1594.7107, 1271.4198, 3608.6928, 4289.7523, 1356.2598, 1802.5623, 912.13364, 616.12245, 636.21812, 620.84032, 3242.0829, 662.63795, 1232.9762, 623.28778, 13618.092, 2220.0401, 1098.4936, 675.83798, 11818.513, 3880.8935, 8037.8773, 4624.485, 631.49729, 2203.174, 2157.3799, 3608.6928, 13504.46, 830.46452, 835.65911, 12602.397, 642.63175, 1379.7682, 638.22003, 628.84156, 5929.6348, 657.32418, 3608.6928, 3608.6928, 12504.069, 4038.2896, 619.38816, 1391.4525, 5927.2816, 8105.1672, 6617.3589, 801.2965, 998.38389, 809.77996, 2622.9563, 1219.8037, 662.1234, 10462.129, 638.58158, 1048.788, 2116.5957, 3607.3133, 7280.6499, 1485.3963, 4079.4074, 799.61232, 1885.1958, 1137.7077, 13585.678, 970.89372, 615.51615, 4313.3253, 2512.8212, 10141.768, 2048.6462, 628.39306, 6135.306, 6823.3885, 698.66838, 3898.9912, 781.92811, 6899.3011, 842.90949, 820.8779, 1780.1898, 1990.8779, 883.9214, 742.56965, 1572.1745, 5684.86, 993.93808, 617.36197, 3942.5717, 620.54297, 3608.6928, 5035.2935, 1065.2102, 1110.4423, 3527.6808, 3880.8935, 672.04075, 1018.5329, 688.03304, 624.00117, 830.98134, 680.7798, 1723.8148, 617.83788, 3880.8935, 1262.9394, 4382.3062, 868.39626, 13224.885, 756.38391, 3608.6928, 616.07741, 732.09657, 3880.8935, 3880.8935, 616.69482, 1700.0409, 622.99311, 668.83826, 3880.8935, 2203.174, 1222.3924, 1029.3653, 7534.9589, 1591.0549, 3880.8935, 1246.9465, 12749.726, 2451.0452, 1038.9519, 1062.4644, 10469.825, 6548.7445, 1365.81, 12101.199, 2451.0452, 2535.6691, 3608.6928, 1273.3006, 1946.3078, 13268.757, 3608.6928, 7044.4326, 13102.392, 2942.23, 857.30083, 615.38035, 623.1969, 813.93864, 3880.8935, 3880.8935, 5759.6105, 2057.8115, 4183.637, 1017.2548, 1203.1282, 1391.4525, 854.27029, 810.35281, 2048.6462, 2100.1067, 1841.0568, 754.62411, 687.88126, 1139.1009, 2376.105, 627.27392, 677.6215, 869.94842, 3880.8935, 1881.3988, 1948.1721, 644.54201, 1141.977, 671.16823, 667.95143, 11100.832, 790.08348, 3608.6928, 630.28107, 659.81254, 758.75808, 628.86695, 1007.4378, 618.09667, 3608.6928, 873.29506, 642.70401, 9949.4959, 1573.6718, 1016.5002, 9982.4907, 653.44489, 749.5331, 12310.307, 1704.6216, 13507.464, 2203.174, 906.5862, 10101.732, 2203.174, 629.54234, 722.84138, 642.21837, 2203.174, 9473.044, 1549.29, 683.94123, 658.49236, 3608.6928, 985.96507, 1594.1077, 12988.976, 792.71984, 1203.2828, 1541.4113, 750.63533, 13616.672, 618.53165, 1341.1318, 624.40082, 667.33174, 668.21091, 2652.1584, 1546.314, 3608.6928, 9550.4794, 4902.1595, 3880.8935, 1702.7732, 1813.0069, 2303.1637, 1869.8685, 1681.6866, 3880.8935, 13147.947, 1780.2805, 3608.6928, 616.53078, 631.72413, 2048.6462, 1755.7291, 729.58617, 1090.6704, 826.35988, 725.12057, 2220.4464, 3506.27, 1193.0168, 1175.5399, 3880.8935, 785.64002, 1588.2995, 661.0586, 2277.5867, 1611.0899, 957.25476, 761.77234, 1001.5966, 8575.7824, 654.71347, 615.53054, 697.03745, 2048.6462, 862.82188, 2048.6462, 620.44303, 3835.4544, 666.44446, 674.87283, 647.50779, 639.40252, 5116.562, 647.90655, 3608.6928, 2203.174, 13519.051, 645.50497, 6769.9915, 2203.174, 1930.4452, 818.33342, 6084.4466, 804.17772, 3525.8314, 1572.0145, 2353.9907, 727.05487, 10665.426, 666.29196, 1335.0941, 13195.163, 2358.7447, 643.83672, 5316.6053, 2779.4672, 7086.0131, 1352.9719, 2388.3629, 2886.0156, 3608.6928, 672.76918, 3880.8935, 647.53954, 630.36156, 1990.7365, 6269.3958, 3880.8935, 11418.977, 630.25684, 3608.6928, 1350.5873, 4351.6163, 788.44186, 698.54921, 664.86896, 5345.2296, 844.6812, 10678.182, 13618.095, 654.40328, 1290.4375, 13616.373, 986.29766, 12019.396, 1439.7253, 6336.5857, 1151.2546, 2240.8597, 1266.548, 793.88609, 836.75851, 794.33743, 3608.6928, 745.65393, 623.66609, 2203.174, 7067.6462, 672.65097, 2048.6462, 7878.91, 622.59868, 4831.1125, 3880.8935, 8415.4635, 9508.1474, 1985.747, 1079.5411, 3608.6928, 3608.6928, 5066.0734, 3608.6928, 1130.5582, 635.67117, 1208.7342, 1086.0861, 1426.1571, 3608.6928, 3788.897, 1263.1019, 12290.146, 2203.174, 1607.2813, 11676.326, 675.30985, 8694.2203, 7360.4656, 922.96541, 732.70099, 1161.5731, 5463.171, 904.66226, 930.55186, 5035.1258, 3272.8703, 4600.2502, 2740.9208, 632.25744, 2048.6462, 2122.9297, 871.68538, 1779.3033, 1176.8816, 622.72477, 5740.4558, 1980.73, 2224.9483, 711.82005, 11931.381, 2451.0452, 1689.6776, 1306.3707, 1040.2987, 1974.7559, 736.3692, 2131.7975, 2451.0452, 678.91612, 1158.1527, 1892.9067, 3140.0828, 633.20418, 1421.6265, 1271.2434, 2203.174, 706.6711, 5989.2023, 941.19335, 631.05698, 3608.6928, 1539.0729, 3608.6928, 636.66951, 667.75893, 615.86486, 6856.1459, 1022.43, 2483.5299, 631.72354, 681.09415, 617.74164, 721.95823, 4367.789, 1504.7831, 12773.061, 770.40586, 781.99541, 846.0449, 901.48865, 1463.0994, 687.97235, 620.05509, 2048.6462, 849.3714, 3608.6928, 3640.1653, 2549.1202, 1279.8331, 6079.9549, 790.68197, 2486.5852, 3373.1742, 5142.5639, 11297.425, 758.40151, 742.64686, 2220.999, 754.8593, 7600.8774, 2048.6462, 615.75806, 831.57544, 615.37484, 3880.8935, 1389.425, 1081.6538, 661.4672, 3608.6928, 5344.0711, 760.20518, 1538.4223, 2048.6462, 648.18548, 691.81846, 728.63704, 619.54268, 3608.6928, 990.67239, 712.99787, 616.40296, 3880.8935, 1323.1716, 637.36707, 1786.1134, 6227.6011, 763.96818, 7699.0038, 3880.8935, 1102.3354, 5419.2916, 11567.265, 2098.1643, 1106.3579, 2425.1532, 738.06274, 949.24711, 11177.668, 3937.5277, 2203.174, 896.95094, 781.99443, 1386.8307, 615.45808, 2274.9787, 3608.6928, 620.69243, 2607.9956, 738.89982, 975.44886, 1891.2439, 2662.6236, 693.47115, 792.86538, 3880.8935, 623.12455, 647.22774, 892.79084, 615.65037, 5601.1002, 1802.0438, 673.31697, 633.02022, 11954.959, 1335.6453, 2451.0452, 2143.0256, 689.82606, 1989.6236, 6647.7947, 632.49864, 1415.071, 718.77527, 3608.6928, 967.93109, 652.4046, 8848.0829, 3608.6928, 768.66076, 631.58325, 930.69308, 5367.3196, 6263.8922, 12084.192, 646.20176, 676.22076, 709.10024, 3608.6928, 3626.3349, 1070.4323, 650.36028, 649.76416, 656.43268, 619.46957, 2676.0111, 927.60497, 950.76978, 1069.2532, 8794.5018, 725.59669, 6641.6079, 3853.0129, 628.7129, 9009.2562, 631.07877, 2470.4213, 10951.832, 3880.8935, 1263.4164, 655.01201, 1344.8985, 6426.5028, 1404.3261, 624.46824, 615.37811, 2783.1212, 1356.9293, 1063.7076, 684.3755, 2048.6462, 4077.1034, 635.15403, 3512.2223, 1230.4873, 11857.658, 6411.9501, 1033.1736, 3608.6928, 881.90607, 616.94816, 3608.6928, 2203.174, 3735.1963, 615.78376, 2435.2412, 622.11737, 883.83925, 685.68397, 7542.479, 1346.6638, 620.01541, 790.70592, 13451.841, 3608.6928, 666.48381, 1705.522, 1039.5029, 1299.4305, 4575.2032, 3821.7738, 637.75931, 2155.4988, 1391.4525, 2048.6462, 1659.3038, 2019.4268, 626.6712, 894.03607, 2048.6462, 622.04026, 13594.891, 3668.0516, 617.35231, 1700.5765, 731.45526, 6369.8708, 3880.8935, 825.21804, 663.32413, 13206.885, 733.41114, 934.27974, 10503.247, 1589.4059, 926.93684, 662.06559, 2048.6462, 11429.914, 620.13587, 3942.6793, 619.01175, 737.00393, 5895.1089, 7578.4781, 3608.6928, 5417.7398, 1149.0814, 2152.6126, 3608.6928, 632.09877, 1648.6541, 2617.6633, 6767.0351, 2014.4114, 910.38454, 3295.9916, 3608.6928, 1940.9898, 12262.355, 907.5091, 1977.9224, 4589.3987, 716.56685, 1659.7061, 625.99287, 1402.8479, 694.68393, 11706.43, 852.41882, 653.13459, 3880.8935, 3534.2959, 913.07658, 963.74836, 623.46118, 3608.6928, 719.8404, 829.69951, 13609.451, 4487.2816, 2048.6462, 672.31101, 3608.6928, 3880.8935, 4922.349, 6280.464, 1038.0949, 3608.6928, 3608.6928, 2048.6462, 2167.786, 618.28085, 1013.6942, 684.13649, 10341.966, 757.09736, 729.30982, 8188.7959, 2451.0452, 3608.6928, 714.20574, 618.68503, 8448.798, 654.27099, 2538.744, 2203.174, 3608.6928, 620.89644, 3880.8935, 1429.045, 827.85916, 2051.1835, 1182.8386, 1091.279, 672.96198, 1354.8013, 620.13535, 1021.8324, 3608.6928, 1703.8439, 3880.8935, 4180.5953, 2529.1318, 2239.0422, 5207.6531, 2401.5811, 848.22518, 3515.4357, 627.59946, 1161.6651, 9872.8742, 5331.6354, 2413.1625, 2048.6462, 1514.0491, 3608.6928, 664.54365, 3880.8935, 808.53382, 661.86434, 702.25789, 697.78624, 1529.0289, 1170.7474, 2885.6127, 885.38539, 7476.9428, 3458.4959, 616.90028, 1122.1151, 625.62535, 11650.11, 10355.688, 3608.6928, 1876.3017, 3608.6928, 630.42447, 12152.404, 3880.8935, 803.88425, 2451.0452, 3880.8935, 12871.806, 2209.5707, 1022.1948, 646.97658, 3608.6928, 630.28422, 3608.6928, 7025.4444, 1531.6881, 3487.8474, 618.54872, 760.71054, 919.64181, 3880.8935, 3608.6928, 647.71033, 629.44882, 3351.5389, 1176.8058, 631.08179, 654.65406, 2048.6462, 1321.4187, 860.12591, 622.77988, 631.53784, 2048.6462, 7589.3973, 4237.8456, 3371.5174, 1747.9897, 2504.8346, 2157.2967, 656.70942, 4399.1414, 2003.6967, 13496.674, 11704.075, 6471.0687, 1271.6364, 1356.812, 639.73997, 838.17572, 3608.6928, 772.12875, 940.39144, 1051.4574, 646.05365, 616.73697, 3240.9916, 6305.5876, 11745.877, 770.34652, 3544.0106, 2203.174, 734.18182, 2203.174, 967.74932, 1041.2537, 11293.052, 626.2689, 5378.035, 3608.6928, 630.90412, 795.79688, 615.49609, 620.32459, 960.55719, 8557.1802, 1339.5498, 2646.7494, 663.58636, 776.57113, 911.68821, 2048.6462, 8879.64, 1423.6603, 3607.2656, 3564.0196, 735.92027, 995.96189, 1320.0578, 660.62885, 977.10117, 1929.5426, 1777.6561, 710.6475, 642.99761, 968.81033, 8185.0139, 623.01142, 648.45415, 845.3153, 993.22499, 957.94164, 1955.1288, 2079.874, 3253.6506, 741.19555, 2583.785, 13532.15, 747.54684, 1876.9435, 1510.3819, 5057.7275, 987.38923, 619.37331, 640.87258, 3395.4305, 652.32945, 4596.1203, 4016.5323, 12822.019, 715.25442, 3880.8935, 3067.4042, 9903.4822, 2203.174, 701.44205, 10916.379, 11550.065, 1705.6351, 746.43966, 1388.2411, 1425.8512, 650.6844, 3880.8935, 13065.633, 2203.174, 1121.2833, 724.8182, 664.67454, 620.63401, 794.38663, 803.51967, 1184.8472, 639.34992, 639.30015, 790.09081, 2401.6124, 2177.1996, 2149.4274, 648.4412, 10394.516, 1417.2154, 646.76162, 2604.0591, 8674.1198, 986.22664, 615.8529, 748.92468, 9083.4685, 665.01579, 4929.8707, 3608.6928, 3880.8935, 6108.1419, 2813.3808, 694.54122, 916.02141, 1462.026, 1043.8546, 4422.6672, 3094.7024, 778.37981, 13611.401, 965.03607, 2205.0761, 4317.8375, 1813.0153, 10119.38, 1027.5535, 1067.6803, 11754.693, 2227.2652, 11143.783, 873.08535, 1597.6912, 1559.3008, 1044.7488, 757.91239, 5210.1916, 3738.3705, 654.70661, 761.74104, 13236.386, 3306.3308, 2360.7035, 615.54732, 674.85551, 3880.8935, 787.8024, 990.47973, 804.89785, 3880.8935, 5094.8758, 2357.137, 633.96078, 616.10087, 837.0647, 1911.5574, 4456.287, 3880.8935, 626.61714, 3880.8935, 4303.3417, 724.43933, 3880.8935, 839.38249, 621.34876, 616.38366, 625.4707, 690.11323, 13574.484, 2478.2183, 1285.4771]
        for i,event in enumerate(lhe):
            
            rwgt_data = event.parse_reweight()
            self.assertTrue('SINGLE' in rwgt_data)
            self.assertTrue('NAME_0' in rwgt_data)
            self.assertTrue('NAME_1' in rwgt_data)
            self.assertEqual(rwgt_data['NAME_1'],rwgt_data['SINGLE'])
            
            solutions1.append(rwgt_data['NAME_0'])
            solutions2.append(rwgt_data['NAME_1'])
            self.assertTrue(misc.equal(rwgt_data['NAME_0'], solutions1[i]))
            self.assertTrue(misc.equal(rwgt_data['NAME_1'], solutions2[i]))
            

    def test_nlo_reweighting_comb(self):
        """check that nlo reweighting is working.
           The main point is to check the recombination of the weights
           Since the rest should be either checked by the lhe_parser class
           or by the various check of the standalone checks
        """
        
        # create a reweight directory   
        interface = MGCmd.MasterCmd()  
        interface.exec_cmd("import model loop_sm", errorhandling=False)
        interface.exec_cmd("set group_subprocesses False")
        interface.exec_cmd("generate u d~ > e+ ve [virt=QCD]", precmd=True, errorhandling=False)
        interface.exec_cmd('output standalone_rw %s/rw_mevirt -f' % self.path)
        # update the makefile:
        # update make_opts
        m_opts = {}
        if interface.options['lhapdf']:
            #lhapdfversion = subprocess.Popen([mgcmd.options['lhapdf'], '--version'], 
            #        stdout = subprocess.PIPE).stdout.read().strip()[0]
            m_opts['lhapdf'] = True
            m_opts['lhapdfversion'] = 5 # 6 always fail on my computer since 5 is compatible but slower always use 5
            m_opts['llhapdf'] = subprocess.Popen([interface.options['lhapdf'], '--libs'], 
                    stdout = subprocess.PIPE).stdout.read().strip().split()[0]
            m_opts['f2pymode'] = True
        else:
            raise Exception, "need LHAPDF"
            lhapdf = False
            lhapdfversion = 0

        path = pjoin(self.path,'rw_mevirt', 'Source', 'make_opts')
        
        commonCmd.CommonRunCmd.update_make_opts_full(path, m_opts)
    
    
        # Now compile the Source directory
        misc.compile(cwd=pjoin(self.path, 'rw_mevirt', 'Source'))
        #link it 
        with misc.chdir(pjoin(self.path)):
            if self.path not in sys.path:
                sys.path.insert(0, self.path)
            mod_name = 'rw_mevirt.Source.rwgt2py'
            if mod_name in sys.modules.keys():
                del sys.modules[mod_name]
                tmp_mod_name = mod_name
                while '.' in tmp_mod_name:
                    tmp_mod_name = tmp_mod_name.rsplit('.',1)[0]
                    del sys.modules[tmp_mod_name]
                mymod = __import__(mod_name, globals(), locals(), [],-1)  
            else:
                mymod = __import__(mod_name, globals(), locals(), [],-1) 
                
            mymod =  mymod.Source.rwgt2py
            #mymod.initialise([1,1], 244600)
       
            scales2 =  [[1283.6655, 1283.6655], [1283.6655, 1283.6655], [1283.6655, 1283.6655]] 
            pdg =  [[21, 21], [2, 2]] 
            bjx =  [[0.00036333765, 0.00036942677], [0.5007504, 0.51807252]] 
            wgt =  [[-1.0551457726, 0.890469566701], [0.0, 0.0], [0.0, 0.0]] 
            gs =  [1.3206738, 1.3206738] 
            qcdpower =  [2, 2] 
            orig_wgt =  -0.28722482722716736 
            ref_wgts =  [-1.8403634002861815, 1.5531385730590141] 
       

        #value = mymod.test_pdf() 
        #self.assertAlmostEqual(value, 1.0)
            
        out, partial = mymod.get_wgt(scales2, pdg, bjx, wgt, gs, qcdpower, 1., 1.)  
        #print ref_wgts, partial, [partial[i]/ref_wgts[i] for i in range(2)]
        #print out, orig_wgt, out/orig_wgt
        self.assertAlmostEqual(partial[0], ref_wgts[0], places=2)
        self.assertAlmostEqual(partial[1], ref_wgts[1], places=2)
        self.assertAlmostEqual(out, orig_wgt, places=2)
        
        
        
        
        #if True and __debug__: #this is only for trivial reweighting
        #    if not misc.equal(out, orig_wgt,1):
        #        misc.sprint(event)
        #        for i, computed in enumerate(partial):
        #            if not misc.equal(computed, ref_wgts[i], 3):
        #                misc.sprint("fail since %s != %s for wgt %s " % (computed, ref_wgts[i], i))
        #                misc.sprint(need_V, R, ratio_T)
        #        misc.sprint("fail since %s != %s for the sum." % (out, orig_wgt))
        #        misc.sprint( need_V, R, ratio_T)
        #        raw_input()
                

            
        
        
                           
        
           
           
           
        
        
        
